# datadog-api-client.v1
Collection of all Datadog Public endpoints.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.datadoghq.com/support/](https://www.datadoghq.com/support/)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/DataDog/datadog-api-client-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/DataDog/datadog-api-client-python.git`)

Then import the package:
```python
import datadog_api_client.v1
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import datadog_api_client.v1
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import datadog_api_client.v1
from pprint import pprint
from datadog_api_client.v1.api import aws_integration_api
from datadog_api_client.v1.model.api_error_response import APIErrorResponse
from datadog_api_client.v1.model.aws_account import AWSAccount
from datadog_api_client.v1.model.aws_account_create_response import AWSAccountCreateResponse
from datadog_api_client.v1.model.aws_account_list_response import AWSAccountListResponse
from datadog_api_client.v1.model.aws_tag_filter_create_request import AWSTagFilterCreateRequest
from datadog_api_client.v1.model.aws_tag_filter_delete_request import AWSTagFilterDeleteRequest
from datadog_api_client.v1.model.aws_tag_filter_list_response import AWSTagFilterListResponse
# See configuration.py for a list of all supported configuration parameters.
configuration = Configuration()

# Defining the site is optional and defaults to datadoghq.com
if "DD_SITE" in os.environ:
    configuration.server_variables["site"] = os.environ["DD_SITE"]

# Configure API key authorization: apiKeyAuth
configuration.api_key['apiKeyAuth'] = os.getenv('DD_CLIENT_API_KEY')

# Configure API key authorization: appKeyAuth
configuration.api_key['appKeyAuth'] = os.getenv('DD_CLIENT_APP_KEY')


# Enter a context with an instance of the API client
with datadog_api_client.v1.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aws_integration_api.AWSIntegrationApi(api_client)
    body = AWSAccount(
        access_key_id="access_key_id_example",
        account_id="1234567",
        account_specific_namespace_rules={
            "key": True,
        },
        excluded_regions=["us-east-1","us-west-2"],
        filter_tags=["<KEY>:<VALUE>"],
        host_tags=["<KEY>:<VALUE>"],
        role_name="DatadogAWSIntegrationRole",
        secret_access_key="secret_access_key_example",
    ) # AWSAccount | AWS Request Object

    try:
        # Create an AWS integration
        api_response = api_instance.create_aws_account(body)
        pprint(api_response)
    except datadog_api_client.v1.ApiException as e:
        print("Exception when calling AWSIntegrationApi->create_aws_account: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.datadoghq.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AWSIntegrationApi* | [**create_aws_account**](AWSIntegrationApi.md#create_aws_account) | **POST** /api/v1/integration/aws | Create an AWS integration
*AWSIntegrationApi* | [**create_aws_tag_filter**](AWSIntegrationApi.md#create_aws_tag_filter) | **POST** /api/v1/integration/aws/filtering | Set an AWS tag filter
*AWSIntegrationApi* | [**create_new_aws_external_id**](AWSIntegrationApi.md#create_new_aws_external_id) | **PUT** /api/v1/integration/aws/generate_new_external_id | Generate a new external ID
*AWSIntegrationApi* | [**delete_aws_account**](AWSIntegrationApi.md#delete_aws_account) | **DELETE** /api/v1/integration/aws | Delete an AWS integration
*AWSIntegrationApi* | [**delete_aws_tag_filter**](AWSIntegrationApi.md#delete_aws_tag_filter) | **DELETE** /api/v1/integration/aws/filtering | Delete a tag filtering entry
*AWSIntegrationApi* | [**list_available_aws_namespaces**](AWSIntegrationApi.md#list_available_aws_namespaces) | **GET** /api/v1/integration/aws/available_namespace_rules | List namespace rules
*AWSIntegrationApi* | [**list_aws_accounts**](AWSIntegrationApi.md#list_aws_accounts) | **GET** /api/v1/integration/aws | List all AWS integrations
*AWSIntegrationApi* | [**list_aws_tag_filters**](AWSIntegrationApi.md#list_aws_tag_filters) | **GET** /api/v1/integration/aws/filtering | Get all AWS tag filters
*AWSIntegrationApi* | [**update_aws_account**](AWSIntegrationApi.md#update_aws_account) | **PUT** /api/v1/integration/aws | Update an AWS integration
*AWSLogsIntegrationApi* | [**check_aws_logs_lambda_async**](AWSLogsIntegrationApi.md#check_aws_logs_lambda_async) | **POST** /api/v1/integration/aws/logs/check_async | Check that an AWS Lambda Function exists
*AWSLogsIntegrationApi* | [**check_aws_logs_services_async**](AWSLogsIntegrationApi.md#check_aws_logs_services_async) | **POST** /api/v1/integration/aws/logs/services_async | Check permissions for log services
*AWSLogsIntegrationApi* | [**create_aws_lambda_arn**](AWSLogsIntegrationApi.md#create_aws_lambda_arn) | **POST** /api/v1/integration/aws/logs | Add AWS Log Lambda ARN
*AWSLogsIntegrationApi* | [**delete_aws_lambda_arn**](AWSLogsIntegrationApi.md#delete_aws_lambda_arn) | **DELETE** /api/v1/integration/aws/logs | Delete an AWS Logs integration
*AWSLogsIntegrationApi* | [**enable_aws_log_services**](AWSLogsIntegrationApi.md#enable_aws_log_services) | **POST** /api/v1/integration/aws/logs/services | Enable an AWS Logs integration
*AWSLogsIntegrationApi* | [**list_aws_logs_integrations**](AWSLogsIntegrationApi.md#list_aws_logs_integrations) | **GET** /api/v1/integration/aws/logs | List all AWS Logs integrations
*AWSLogsIntegrationApi* | [**list_aws_logs_services**](AWSLogsIntegrationApi.md#list_aws_logs_services) | **GET** /api/v1/integration/aws/logs/services | Get list of AWS log ready services
*AuthenticationApi* | [**validate**](AuthenticationApi.md#validate) | **GET** /api/v1/validate | Validate API key
*AzureIntegrationApi* | [**create_azure_integration**](AzureIntegrationApi.md#create_azure_integration) | **POST** /api/v1/integration/azure | Create an Azure integration
*AzureIntegrationApi* | [**delete_azure_integration**](AzureIntegrationApi.md#delete_azure_integration) | **DELETE** /api/v1/integration/azure | Delete an Azure integration
*AzureIntegrationApi* | [**list_azure_integration**](AzureIntegrationApi.md#list_azure_integration) | **GET** /api/v1/integration/azure | List all Azure integrations
*AzureIntegrationApi* | [**update_azure_host_filters**](AzureIntegrationApi.md#update_azure_host_filters) | **POST** /api/v1/integration/azure/host_filters | Update Azure integration host filters
*AzureIntegrationApi* | [**update_azure_integration**](AzureIntegrationApi.md#update_azure_integration) | **PUT** /api/v1/integration/azure | Update an Azure integration
*DashboardListsApi* | [**create_dashboard_list**](DashboardListsApi.md#create_dashboard_list) | **POST** /api/v1/dashboard/lists/manual | Create a dashboard list
*DashboardListsApi* | [**delete_dashboard_list**](DashboardListsApi.md#delete_dashboard_list) | **DELETE** /api/v1/dashboard/lists/manual/{list_id} | Delete a dashboard list
*DashboardListsApi* | [**get_dashboard_list**](DashboardListsApi.md#get_dashboard_list) | **GET** /api/v1/dashboard/lists/manual/{list_id} | Get a dashboard list
*DashboardListsApi* | [**list_dashboard_lists**](DashboardListsApi.md#list_dashboard_lists) | **GET** /api/v1/dashboard/lists/manual | Get all dashboard lists
*DashboardListsApi* | [**update_dashboard_list**](DashboardListsApi.md#update_dashboard_list) | **PUT** /api/v1/dashboard/lists/manual/{list_id} | Update a dashboard list
*DashboardsApi* | [**create_dashboard**](DashboardsApi.md#create_dashboard) | **POST** /api/v1/dashboard | Create a new dashboard
*DashboardsApi* | [**delete_dashboard**](DashboardsApi.md#delete_dashboard) | **DELETE** /api/v1/dashboard/{dashboard_id} | Delete a dashboard
*DashboardsApi* | [**get_dashboard**](DashboardsApi.md#get_dashboard) | **GET** /api/v1/dashboard/{dashboard_id} | Get a dashboard
*DashboardsApi* | [**list_dashboards**](DashboardsApi.md#list_dashboards) | **GET** /api/v1/dashboard | Get all dashboards
*DashboardsApi* | [**update_dashboard**](DashboardsApi.md#update_dashboard) | **PUT** /api/v1/dashboard/{dashboard_id} | Update a dashboard
*DowntimesApi* | [**cancel_downtime**](DowntimesApi.md#cancel_downtime) | **DELETE** /api/v1/downtime/{downtime_id} | Cancel a downtime
*DowntimesApi* | [**cancel_downtimes_by_scope**](DowntimesApi.md#cancel_downtimes_by_scope) | **POST** /api/v1/downtime/cancel/by_scope | Cancel downtimes by scope
*DowntimesApi* | [**create_downtime**](DowntimesApi.md#create_downtime) | **POST** /api/v1/downtime | Schedule a downtime
*DowntimesApi* | [**get_downtime**](DowntimesApi.md#get_downtime) | **GET** /api/v1/downtime/{downtime_id} | Get a downtime
*DowntimesApi* | [**list_downtimes**](DowntimesApi.md#list_downtimes) | **GET** /api/v1/downtime | Get all downtimes
*DowntimesApi* | [**update_downtime**](DowntimesApi.md#update_downtime) | **PUT** /api/v1/downtime/{downtime_id} | Update a downtime
*EventsApi* | [**get_event**](EventsApi.md#get_event) | **GET** /api/v1/events/{event_id} | Get an event
*EventsApi* | [**list_events**](EventsApi.md#list_events) | **GET** /api/v1/events | Query the event stream
*GCPIntegrationApi* | [**create_gcp_integration**](GCPIntegrationApi.md#create_gcp_integration) | **POST** /api/v1/integration/gcp | Create a GCP integration
*GCPIntegrationApi* | [**delete_gcp_integration**](GCPIntegrationApi.md#delete_gcp_integration) | **DELETE** /api/v1/integration/gcp | Delete a GCP integration
*GCPIntegrationApi* | [**list_gcp_integration**](GCPIntegrationApi.md#list_gcp_integration) | **GET** /api/v1/integration/gcp | List all GCP integrations
*GCPIntegrationApi* | [**update_gcp_integration**](GCPIntegrationApi.md#update_gcp_integration) | **PUT** /api/v1/integration/gcp | Update a GCP integration
*HostsApi* | [**get_host_totals**](HostsApi.md#get_host_totals) | **GET** /api/v1/hosts/totals | Get the total number of active hosts
*HostsApi* | [**list_hosts**](HostsApi.md#list_hosts) | **GET** /api/v1/hosts | Get all hosts for your organization
*HostsApi* | [**mute_host**](HostsApi.md#mute_host) | **POST** /api/v1/host/{host_name}/mute | Mute a host
*HostsApi* | [**unmute_host**](HostsApi.md#unmute_host) | **POST** /api/v1/host/{host_name}/unmute | Unmute a host
*IPRangesApi* | [**get_ip_ranges**](IPRangesApi.md#get_ip_ranges) | **GET** / | List IP Ranges
*KeyManagementApi* | [**create_api_key**](KeyManagementApi.md#create_api_key) | **POST** /api/v1/api_key | Create an API key
*KeyManagementApi* | [**create_application_key**](KeyManagementApi.md#create_application_key) | **POST** /api/v1/application_key | Create an application key
*KeyManagementApi* | [**delete_api_key**](KeyManagementApi.md#delete_api_key) | **DELETE** /api/v1/api_key/{key} | Delete an API key
*KeyManagementApi* | [**delete_application_key**](KeyManagementApi.md#delete_application_key) | **DELETE** /api/v1/application_key/{key} | Delete an application key
*KeyManagementApi* | [**get_api_key**](KeyManagementApi.md#get_api_key) | **GET** /api/v1/api_key/{key} | Get API key
*KeyManagementApi* | [**get_application_key**](KeyManagementApi.md#get_application_key) | **GET** /api/v1/application_key/{key} | Get an application key
*KeyManagementApi* | [**list_api_keys**](KeyManagementApi.md#list_api_keys) | **GET** /api/v1/api_key | Get all API keys
*KeyManagementApi* | [**list_application_keys**](KeyManagementApi.md#list_application_keys) | **GET** /api/v1/application_key | Get all application keys
*KeyManagementApi* | [**update_api_key**](KeyManagementApi.md#update_api_key) | **PUT** /api/v1/api_key/{key} | Edit an API key
*KeyManagementApi* | [**update_application_key**](KeyManagementApi.md#update_application_key) | **PUT** /api/v1/application_key/{key} | Edit an application key
*LogsApi* | [**list_logs**](LogsApi.md#list_logs) | **POST** /api/v1/logs-queries/list | Search logs
*LogsIndexesApi* | [**create_logs_index**](LogsIndexesApi.md#create_logs_index) | **POST** /api/v1/logs/config/indexes | Create an index
*LogsIndexesApi* | [**get_logs_index**](LogsIndexesApi.md#get_logs_index) | **GET** /api/v1/logs/config/indexes/{name} | Get an index
*LogsIndexesApi* | [**get_logs_index_order**](LogsIndexesApi.md#get_logs_index_order) | **GET** /api/v1/logs/config/index-order | Get indexes order
*LogsIndexesApi* | [**list_log_indexes**](LogsIndexesApi.md#list_log_indexes) | **GET** /api/v1/logs/config/indexes | Get all indexes
*LogsIndexesApi* | [**update_logs_index**](LogsIndexesApi.md#update_logs_index) | **PUT** /api/v1/logs/config/indexes/{name} | Update an index
*LogsIndexesApi* | [**update_logs_index_order**](LogsIndexesApi.md#update_logs_index_order) | **PUT** /api/v1/logs/config/index-order | Update indexes order
*LogsPipelinesApi* | [**create_logs_pipeline**](LogsPipelinesApi.md#create_logs_pipeline) | **POST** /api/v1/logs/config/pipelines | Create a pipeline
*LogsPipelinesApi* | [**delete_logs_pipeline**](LogsPipelinesApi.md#delete_logs_pipeline) | **DELETE** /api/v1/logs/config/pipelines/{pipeline_id} | Delete a pipeline
*LogsPipelinesApi* | [**get_logs_pipeline**](LogsPipelinesApi.md#get_logs_pipeline) | **GET** /api/v1/logs/config/pipelines/{pipeline_id} | Get a pipeline
*LogsPipelinesApi* | [**get_logs_pipeline_order**](LogsPipelinesApi.md#get_logs_pipeline_order) | **GET** /api/v1/logs/config/pipeline-order | Get pipeline order
*LogsPipelinesApi* | [**list_logs_pipelines**](LogsPipelinesApi.md#list_logs_pipelines) | **GET** /api/v1/logs/config/pipelines | Get all pipelines
*LogsPipelinesApi* | [**update_logs_pipeline**](LogsPipelinesApi.md#update_logs_pipeline) | **PUT** /api/v1/logs/config/pipelines/{pipeline_id} | Update a pipeline
*LogsPipelinesApi* | [**update_logs_pipeline_order**](LogsPipelinesApi.md#update_logs_pipeline_order) | **PUT** /api/v1/logs/config/pipeline-order | Update pipeline order
*MetricsApi* | [**get_metric_metadata**](MetricsApi.md#get_metric_metadata) | **GET** /api/v1/metrics/{metric_name} | Get metric metadata
*MetricsApi* | [**list_active_metrics**](MetricsApi.md#list_active_metrics) | **GET** /api/v1/metrics | Get active metrics list
*MetricsApi* | [**list_metrics**](MetricsApi.md#list_metrics) | **GET** /api/v1/search | Search metrics
*MetricsApi* | [**query_metrics**](MetricsApi.md#query_metrics) | **GET** /api/v1/query | Query timeseries points
*MetricsApi* | [**update_metric_metadata**](MetricsApi.md#update_metric_metadata) | **PUT** /api/v1/metrics/{metric_name} | Edit metric metadata
*MonitorsApi* | [**check_can_delete_monitor**](MonitorsApi.md#check_can_delete_monitor) | **GET** /api/v1/monitor/can_delete | Check if a monitor can be deleted
*MonitorsApi* | [**create_monitor**](MonitorsApi.md#create_monitor) | **POST** /api/v1/monitor | Create a monitor
*MonitorsApi* | [**delete_monitor**](MonitorsApi.md#delete_monitor) | **DELETE** /api/v1/monitor/{monitor_id} | Delete a monitor
*MonitorsApi* | [**get_monitor**](MonitorsApi.md#get_monitor) | **GET** /api/v1/monitor/{monitor_id} | Get a monitor&#39;s details
*MonitorsApi* | [**list_monitors**](MonitorsApi.md#list_monitors) | **GET** /api/v1/monitor | Get all monitor details
*MonitorsApi* | [**update_monitor**](MonitorsApi.md#update_monitor) | **PUT** /api/v1/monitor/{monitor_id} | Edit a monitor
*MonitorsApi* | [**validate_monitor**](MonitorsApi.md#validate_monitor) | **POST** /api/v1/monitor/validate | Validate a monitor
*OrganizationsApi* | [**create_child_org**](OrganizationsApi.md#create_child_org) | **POST** /api/v1/org | Create a child organization
*OrganizationsApi* | [**get_org**](OrganizationsApi.md#get_org) | **GET** /api/v1/org/{public_id} | Get organization information
*OrganizationsApi* | [**list_orgs**](OrganizationsApi.md#list_orgs) | **GET** /api/v1/org | List your managed organizations
*OrganizationsApi* | [**update_org**](OrganizationsApi.md#update_org) | **PUT** /api/v1/org/{public_id} | Update your organization
*OrganizationsApi* | [**upload_id_p_for_org**](OrganizationsApi.md#upload_id_p_for_org) | **POST** /api/v1/org/{public_id}/idp_metadata | Upload IdP metadata
*PagerDutyIntegrationApi* | [**create_pager_duty_integration_service**](PagerDutyIntegrationApi.md#create_pager_duty_integration_service) | **POST** /api/v1/integration/pagerduty/configuration/services | Create a new service object
*PagerDutyIntegrationApi* | [**delete_pager_duty_integration_service**](PagerDutyIntegrationApi.md#delete_pager_duty_integration_service) | **DELETE** /api/v1/integration/pagerduty/configuration/services/{service_name} | Delete a single service object
*PagerDutyIntegrationApi* | [**get_pager_duty_integration_service**](PagerDutyIntegrationApi.md#get_pager_duty_integration_service) | **GET** /api/v1/integration/pagerduty/configuration/services/{service_name} | Get a single service object
*PagerDutyIntegrationApi* | [**update_pager_duty_integration_service**](PagerDutyIntegrationApi.md#update_pager_duty_integration_service) | **PUT** /api/v1/integration/pagerduty/configuration/services/{service_name} | Update a single service object
*ServiceLevelObjectiveCorrectionsApi* | [**create_slo_correction**](ServiceLevelObjectiveCorrectionsApi.md#create_slo_correction) | **POST** /api/v1/slo/correction | Create an SLO correction
*ServiceLevelObjectiveCorrectionsApi* | [**delete_slo_correction**](ServiceLevelObjectiveCorrectionsApi.md#delete_slo_correction) | **DELETE** /api/v1/slo/correction/{slo_correction_id} | Delete an SLO Correction
*ServiceLevelObjectiveCorrectionsApi* | [**get_slo_correction**](ServiceLevelObjectiveCorrectionsApi.md#get_slo_correction) | **GET** /api/v1/slo/correction/{slo_correction_id} | Get an SLO correction for an SLO
*ServiceLevelObjectiveCorrectionsApi* | [**list_slo_correction**](ServiceLevelObjectiveCorrectionsApi.md#list_slo_correction) | **GET** /api/v1/slo/correction | Get all SLO corrections
*ServiceLevelObjectiveCorrectionsApi* | [**update_slo_correction**](ServiceLevelObjectiveCorrectionsApi.md#update_slo_correction) | **PATCH** /api/v1/slo/correction/{slo_correction_id} | Update an SLO Correction
*ServiceLevelObjectivesApi* | [**check_can_delete_slo**](ServiceLevelObjectivesApi.md#check_can_delete_slo) | **GET** /api/v1/slo/can_delete | Check if SLOs can be safely deleted
*ServiceLevelObjectivesApi* | [**create_slo**](ServiceLevelObjectivesApi.md#create_slo) | **POST** /api/v1/slo | Create an SLO object
*ServiceLevelObjectivesApi* | [**delete_slo**](ServiceLevelObjectivesApi.md#delete_slo) | **DELETE** /api/v1/slo/{slo_id} | Delete an SLO
*ServiceLevelObjectivesApi* | [**delete_slo_timeframe_in_bulk**](ServiceLevelObjectivesApi.md#delete_slo_timeframe_in_bulk) | **POST** /api/v1/slo/bulk_delete | Bulk Delete SLO Timeframes
*ServiceLevelObjectivesApi* | [**get_slo**](ServiceLevelObjectivesApi.md#get_slo) | **GET** /api/v1/slo/{slo_id} | Get an SLO&#39;s details
*ServiceLevelObjectivesApi* | [**get_slo_history**](ServiceLevelObjectivesApi.md#get_slo_history) | **GET** /api/v1/slo/{slo_id}/history | Get an SLO&#39;s history
*ServiceLevelObjectivesApi* | [**list_slos**](ServiceLevelObjectivesApi.md#list_slos) | **GET** /api/v1/slo | Get all SLOs
*ServiceLevelObjectivesApi* | [**update_slo**](ServiceLevelObjectivesApi.md#update_slo) | **PUT** /api/v1/slo/{slo_id} | Update an SLO
*SlackIntegrationApi* | [**create_slack_integration_channel**](SlackIntegrationApi.md#create_slack_integration_channel) | **POST** /api/v1/integration/slack/configuration/accounts/{account_name}/channels | Create a Slack integration channel
*SlackIntegrationApi* | [**get_slack_integration_channel**](SlackIntegrationApi.md#get_slack_integration_channel) | **GET** /api/v1/integration/slack/configuration/accounts/{account_name}/channels/{channel_name} | Get a Slack integration channel
*SlackIntegrationApi* | [**get_slack_integration_channels**](SlackIntegrationApi.md#get_slack_integration_channels) | **GET** /api/v1/integration/slack/configuration/accounts/{account_name}/channels | Get all channels in a Slack integration
*SlackIntegrationApi* | [**remove_slack_integration_channel**](SlackIntegrationApi.md#remove_slack_integration_channel) | **DELETE** /api/v1/integration/slack/configuration/accounts/{account_name}/channels/{channel_name} | Remove a Slack integration channel
*SlackIntegrationApi* | [**update_slack_integration_channel**](SlackIntegrationApi.md#update_slack_integration_channel) | **PATCH** /api/v1/integration/slack/configuration/accounts/{account_name}/channels/{channel_name} | Update a Slack integration channel
*SnapshotsApi* | [**get_graph_snapshot**](SnapshotsApi.md#get_graph_snapshot) | **GET** /api/v1/graph/snapshot | Take graph snapshots
*SyntheticsApi* | [**create_global_variable**](SyntheticsApi.md#create_global_variable) | **POST** /api/v1/synthetics/variables | Create a global variable
*SyntheticsApi* | [**create_private_location**](SyntheticsApi.md#create_private_location) | **POST** /api/v1/synthetics/private-locations | Create a private location
*SyntheticsApi* | [**create_synthetics_api_test**](SyntheticsApi.md#create_synthetics_api_test) | **POST** /api/v1/synthetics/tests/api | Create an API test
*SyntheticsApi* | [**create_synthetics_browser_test**](SyntheticsApi.md#create_synthetics_browser_test) | **POST** /api/v1/synthetics/tests/browser | Create a browser test
*SyntheticsApi* | [**create_test**](SyntheticsApi.md#create_test) | **POST** /api/v1/synthetics/tests | Create a test
*SyntheticsApi* | [**delete_global_variable**](SyntheticsApi.md#delete_global_variable) | **DELETE** /api/v1/synthetics/variables/{variable_id} | Delete a global variable
*SyntheticsApi* | [**delete_private_location**](SyntheticsApi.md#delete_private_location) | **DELETE** /api/v1/synthetics/private-locations/{location_id} | Delete a private location
*SyntheticsApi* | [**delete_tests**](SyntheticsApi.md#delete_tests) | **POST** /api/v1/synthetics/tests/delete | Delete tests
*SyntheticsApi* | [**edit_global_variable**](SyntheticsApi.md#edit_global_variable) | **PUT** /api/v1/synthetics/variables/{variable_id} | Edit a global variable
*SyntheticsApi* | [**get_api_test_latest_results**](SyntheticsApi.md#get_api_test_latest_results) | **GET** /api/v1/synthetics/tests/{public_id}/results | Get the test&#39;s latest results summaries (API)
*SyntheticsApi* | [**get_api_test_result**](SyntheticsApi.md#get_api_test_result) | **GET** /api/v1/synthetics/tests/{public_id}/results/{result_id} | Get a test result (API)
*SyntheticsApi* | [**get_browser_test**](SyntheticsApi.md#get_browser_test) | **GET** /api/v1/synthetics/tests/browser/{public_id} | Get a test configuration (browser)
*SyntheticsApi* | [**get_browser_test_latest_results**](SyntheticsApi.md#get_browser_test_latest_results) | **GET** /api/v1/synthetics/tests/browser/{public_id}/results | Get the test&#39;s latest results summaries (browser)
*SyntheticsApi* | [**get_browser_test_result**](SyntheticsApi.md#get_browser_test_result) | **GET** /api/v1/synthetics/tests/browser/{public_id}/results/{result_id} | Get a test result (browser)
*SyntheticsApi* | [**get_global_variable**](SyntheticsApi.md#get_global_variable) | **GET** /api/v1/synthetics/variables/{variable_id} | Get a global variable
*SyntheticsApi* | [**get_private_location**](SyntheticsApi.md#get_private_location) | **GET** /api/v1/synthetics/private-locations/{location_id} | Get a private location
*SyntheticsApi* | [**get_test**](SyntheticsApi.md#get_test) | **GET** /api/v1/synthetics/tests/{public_id} | Get a test configuration (API)
*SyntheticsApi* | [**list_locations**](SyntheticsApi.md#list_locations) | **GET** /api/v1/synthetics/locations | Get all locations (public and private)
*SyntheticsApi* | [**list_tests**](SyntheticsApi.md#list_tests) | **GET** /api/v1/synthetics/tests | Get the list of all tests
*SyntheticsApi* | [**trigger_ci_tests**](SyntheticsApi.md#trigger_ci_tests) | **POST** /api/v1/synthetics/tests/trigger/ci | Trigger some Synthetics tests for CI
*SyntheticsApi* | [**update_api_test**](SyntheticsApi.md#update_api_test) | **PUT** /api/v1/synthetics/tests/api/{public_id} | Edit an API test
*SyntheticsApi* | [**update_browser_test**](SyntheticsApi.md#update_browser_test) | **PUT** /api/v1/synthetics/tests/browser/{public_id} | Edit a browser test
*SyntheticsApi* | [**update_private_location**](SyntheticsApi.md#update_private_location) | **PUT** /api/v1/synthetics/private-locations/{location_id} | Edit a private location
*SyntheticsApi* | [**update_test**](SyntheticsApi.md#update_test) | **PUT** /api/v1/synthetics/tests/{public_id} | Edit a test
*SyntheticsApi* | [**update_test_pause_status**](SyntheticsApi.md#update_test_pause_status) | **PUT** /api/v1/synthetics/tests/{public_id}/status | Pause or start a test
*TagsApi* | [**create_host_tags**](TagsApi.md#create_host_tags) | **POST** /api/v1/tags/hosts/{host_name} | Add tags to a host
*TagsApi* | [**delete_host_tags**](TagsApi.md#delete_host_tags) | **DELETE** /api/v1/tags/hosts/{host_name} | Remove host tags
*TagsApi* | [**get_host_tags**](TagsApi.md#get_host_tags) | **GET** /api/v1/tags/hosts/{host_name} | Get host tags
*TagsApi* | [**list_host_tags**](TagsApi.md#list_host_tags) | **GET** /api/v1/tags/hosts | Get Tags
*TagsApi* | [**update_host_tags**](TagsApi.md#update_host_tags) | **PUT** /api/v1/tags/hosts/{host_name} | Update host tags
*UsageMeteringApi* | [**get_daily_custom_reports**](UsageMeteringApi.md#get_daily_custom_reports) | **GET** /api/v1/daily_custom_reports | Get the list of available daily custom reports
*UsageMeteringApi* | [**get_incident_management**](UsageMeteringApi.md#get_incident_management) | **GET** /api/v1/usage/incident-management | Get hourly usage for incident management
*UsageMeteringApi* | [**get_ingested_spans**](UsageMeteringApi.md#get_ingested_spans) | **GET** /api/v1/usage/ingested-spans | Get hourly usage for ingested spans
*UsageMeteringApi* | [**get_monthly_custom_reports**](UsageMeteringApi.md#get_monthly_custom_reports) | **GET** /api/v1/monthly_custom_reports | Get the list of available monthly custom reports
*UsageMeteringApi* | [**get_specified_daily_custom_reports**](UsageMeteringApi.md#get_specified_daily_custom_reports) | **GET** /api/v1/daily_custom_reports/{report_id} | Get specified daily custom reports
*UsageMeteringApi* | [**get_specified_monthly_custom_reports**](UsageMeteringApi.md#get_specified_monthly_custom_reports) | **GET** /api/v1/monthly_custom_reports/{report_id} | Get specified monthly custom reports
*UsageMeteringApi* | [**get_tracing_without_limits**](UsageMeteringApi.md#get_tracing_without_limits) | **GET** /api/v1/usage/tracing-without-limits | Get hourly usage for tracing without limits
*UsageMeteringApi* | [**get_usage_analyzed_logs**](UsageMeteringApi.md#get_usage_analyzed_logs) | **GET** /api/v1/usage/analyzed_logs | Get hourly usage for analyzed logs
*UsageMeteringApi* | [**get_usage_attribution**](UsageMeteringApi.md#get_usage_attribution) | **GET** /api/v1/usage/attribution | Get Usage Attribution
*UsageMeteringApi* | [**get_usage_billable_summary**](UsageMeteringApi.md#get_usage_billable_summary) | **GET** /api/v1/usage/billable-summary | Get billable usage across your account
*UsageMeteringApi* | [**get_usage_fargate**](UsageMeteringApi.md#get_usage_fargate) | **GET** /api/v1/usage/fargate | Get hourly usage for Fargate
*UsageMeteringApi* | [**get_usage_hosts**](UsageMeteringApi.md#get_usage_hosts) | **GET** /api/v1/usage/hosts | Get hourly usage for hosts and containers
*UsageMeteringApi* | [**get_usage_indexed_spans**](UsageMeteringApi.md#get_usage_indexed_spans) | **GET** /api/v1/usage/indexed-spans | Get hourly usage for indexed spans
*UsageMeteringApi* | [**get_usage_internet_of_things**](UsageMeteringApi.md#get_usage_internet_of_things) | **GET** /api/v1/usage/iot | Get hourly usage for IoT
*UsageMeteringApi* | [**get_usage_lambda**](UsageMeteringApi.md#get_usage_lambda) | **GET** /api/v1/usage/aws_lambda | Get hourly usage for Lambda
*UsageMeteringApi* | [**get_usage_logs**](UsageMeteringApi.md#get_usage_logs) | **GET** /api/v1/usage/logs | Get hourly usage for Logs
*UsageMeteringApi* | [**get_usage_logs_by_index**](UsageMeteringApi.md#get_usage_logs_by_index) | **GET** /api/v1/usage/logs_by_index | Get hourly usage for Logs by Index
*UsageMeteringApi* | [**get_usage_network_flows**](UsageMeteringApi.md#get_usage_network_flows) | **GET** /api/v1/usage/network_flows | Get hourly usage for Network Flows
*UsageMeteringApi* | [**get_usage_network_hosts**](UsageMeteringApi.md#get_usage_network_hosts) | **GET** /api/v1/usage/network_hosts | Get hourly usage for Network Hosts
*UsageMeteringApi* | [**get_usage_profiling**](UsageMeteringApi.md#get_usage_profiling) | **GET** /api/v1/usage/profiling | Get hourly usage for profiled hosts
*UsageMeteringApi* | [**get_usage_rum_sessions**](UsageMeteringApi.md#get_usage_rum_sessions) | **GET** /api/v1/usage/rum_sessions | Get hourly usage for RUM Sessions
*UsageMeteringApi* | [**get_usage_snmp**](UsageMeteringApi.md#get_usage_snmp) | **GET** /api/v1/usage/snmp | Get hourly usage for SNMP devices
*UsageMeteringApi* | [**get_usage_summary**](UsageMeteringApi.md#get_usage_summary) | **GET** /api/v1/usage/summary | Get usage across your multi-org account
*UsageMeteringApi* | [**get_usage_synthetics**](UsageMeteringApi.md#get_usage_synthetics) | **GET** /api/v1/usage/synthetics | Get hourly usage for Synthetics Checks
*UsageMeteringApi* | [**get_usage_synthetics_api**](UsageMeteringApi.md#get_usage_synthetics_api) | **GET** /api/v1/usage/synthetics_api | Get hourly usage for Synthetics API Checks
*UsageMeteringApi* | [**get_usage_synthetics_browser**](UsageMeteringApi.md#get_usage_synthetics_browser) | **GET** /api/v1/usage/synthetics_browser | Get hourly usage for Synthetics Browser Checks
*UsageMeteringApi* | [**get_usage_timeseries**](UsageMeteringApi.md#get_usage_timeseries) | **GET** /api/v1/usage/timeseries | Get hourly usage for custom metrics
*UsageMeteringApi* | [**get_usage_top_avg_metrics**](UsageMeteringApi.md#get_usage_top_avg_metrics) | **GET** /api/v1/usage/top_avg_metrics | Get top custom metrics by hourly average
*UsageMeteringApi* | [**get_usage_trace**](UsageMeteringApi.md#get_usage_trace) | **GET** /api/v1/usage/traces | Get hourly usage for Trace Search
*UsersApi* | [**create_user**](UsersApi.md#create_user) | **POST** /api/v1/user | Create a user
*UsersApi* | [**disable_user**](UsersApi.md#disable_user) | **DELETE** /api/v1/user/{user_handle} | Disable a user
*UsersApi* | [**get_user**](UsersApi.md#get_user) | **GET** /api/v1/user/{user_handle} | Get user details
*UsersApi* | [**list_users**](UsersApi.md#list_users) | **GET** /api/v1/user | List all users
*UsersApi* | [**update_user**](UsersApi.md#update_user) | **PUT** /api/v1/user/{user_handle} | Update a user


## Documentation For Models

 - [APIErrorResponse](APIErrorResponse.md)
 - [AWSAccount](AWSAccount.md)
 - [AWSAccountAndLambdaRequest](AWSAccountAndLambdaRequest.md)
 - [AWSAccountCreateResponse](AWSAccountCreateResponse.md)
 - [AWSAccountListResponse](AWSAccountListResponse.md)
 - [AWSLogsAsyncError](AWSLogsAsyncError.md)
 - [AWSLogsAsyncResponse](AWSLogsAsyncResponse.md)
 - [AWSLogsLambda](AWSLogsLambda.md)
 - [AWSLogsListResponse](AWSLogsListResponse.md)
 - [AWSLogsListServicesResponse](AWSLogsListServicesResponse.md)
 - [AWSLogsServicesRequest](AWSLogsServicesRequest.md)
 - [AWSNamespace](AWSNamespace.md)
 - [AWSTagFilter](AWSTagFilter.md)
 - [AWSTagFilterCreateRequest](AWSTagFilterCreateRequest.md)
 - [AWSTagFilterDeleteRequest](AWSTagFilterDeleteRequest.md)
 - [AWSTagFilterListResponse](AWSTagFilterListResponse.md)
 - [AccessRole](AccessRole.md)
 - [AlertGraphWidgetDefinition](AlertGraphWidgetDefinition.md)
 - [AlertGraphWidgetDefinitionType](AlertGraphWidgetDefinitionType.md)
 - [AlertValueWidgetDefinition](AlertValueWidgetDefinition.md)
 - [AlertValueWidgetDefinitionType](AlertValueWidgetDefinitionType.md)
 - [ApiKey](ApiKey.md)
 - [ApiKeyListResponse](ApiKeyListResponse.md)
 - [ApiKeyResponse](ApiKeyResponse.md)
 - [ApmStatsQueryColumnType](ApmStatsQueryColumnType.md)
 - [ApmStatsQueryDefinition](ApmStatsQueryDefinition.md)
 - [ApmStatsQueryRowType](ApmStatsQueryRowType.md)
 - [ApplicationKey](ApplicationKey.md)
 - [ApplicationKeyListResponse](ApplicationKeyListResponse.md)
 - [ApplicationKeyResponse](ApplicationKeyResponse.md)
 - [AuthenticationValidationResponse](AuthenticationValidationResponse.md)
 - [AzureAccount](AzureAccount.md)
 - [AzureAccountListResponse](AzureAccountListResponse.md)
 - [CancelDowntimesByScopeRequest](CancelDowntimesByScopeRequest.md)
 - [CanceledDowntimesIds](CanceledDowntimesIds.md)
 - [ChangeWidgetDefinition](ChangeWidgetDefinition.md)
 - [ChangeWidgetDefinitionType](ChangeWidgetDefinitionType.md)
 - [ChangeWidgetRequest](ChangeWidgetRequest.md)
 - [CheckCanDeleteMonitorResponse](CheckCanDeleteMonitorResponse.md)
 - [CheckCanDeleteMonitorResponseData](CheckCanDeleteMonitorResponseData.md)
 - [CheckCanDeleteSLOResponse](CheckCanDeleteSLOResponse.md)
 - [CheckCanDeleteSLOResponseData](CheckCanDeleteSLOResponseData.md)
 - [CheckStatusWidgetDefinition](CheckStatusWidgetDefinition.md)
 - [CheckStatusWidgetDefinitionType](CheckStatusWidgetDefinitionType.md)
 - [Creator](Creator.md)
 - [Dashboard](Dashboard.md)
 - [DashboardDeleteResponse](DashboardDeleteResponse.md)
 - [DashboardLayoutType](DashboardLayoutType.md)
 - [DashboardList](DashboardList.md)
 - [DashboardListDeleteResponse](DashboardListDeleteResponse.md)
 - [DashboardListListResponse](DashboardListListResponse.md)
 - [DashboardSummary](DashboardSummary.md)
 - [DashboardSummaryDefinition](DashboardSummaryDefinition.md)
 - [DashboardTemplateVariable](DashboardTemplateVariable.md)
 - [DashboardTemplateVariablePreset](DashboardTemplateVariablePreset.md)
 - [DashboardTemplateVariablePresetValue](DashboardTemplateVariablePresetValue.md)
 - [DeletedMonitor](DeletedMonitor.md)
 - [DistributionWidgetDefinition](DistributionWidgetDefinition.md)
 - [DistributionWidgetDefinitionType](DistributionWidgetDefinitionType.md)
 - [DistributionWidgetRequest](DistributionWidgetRequest.md)
 - [Downtime](Downtime.md)
 - [DowntimeRecurrence](DowntimeRecurrence.md)
 - [Event](Event.md)
 - [EventAlertType](EventAlertType.md)
 - [EventListResponse](EventListResponse.md)
 - [EventPriority](EventPriority.md)
 - [EventQueryDefinition](EventQueryDefinition.md)
 - [EventResponse](EventResponse.md)
 - [EventStreamWidgetDefinition](EventStreamWidgetDefinition.md)
 - [EventStreamWidgetDefinitionType](EventStreamWidgetDefinitionType.md)
 - [EventTimelineWidgetDefinition](EventTimelineWidgetDefinition.md)
 - [EventTimelineWidgetDefinitionType](EventTimelineWidgetDefinitionType.md)
 - [FormulaAndFunctionEventAggregation](FormulaAndFunctionEventAggregation.md)
 - [FormulaAndFunctionEventQueryDefinition](FormulaAndFunctionEventQueryDefinition.md)
 - [FormulaAndFunctionEventQueryDefinitionCompute](FormulaAndFunctionEventQueryDefinitionCompute.md)
 - [FormulaAndFunctionEventQueryDefinitionSearch](FormulaAndFunctionEventQueryDefinitionSearch.md)
 - [FormulaAndFunctionEventQueryGroupBy](FormulaAndFunctionEventQueryGroupBy.md)
 - [FormulaAndFunctionEventQueryGroupBySort](FormulaAndFunctionEventQueryGroupBySort.md)
 - [FormulaAndFunctionEventsDataSource](FormulaAndFunctionEventsDataSource.md)
 - [FormulaAndFunctionMetricAggregation](FormulaAndFunctionMetricAggregation.md)
 - [FormulaAndFunctionMetricDataSource](FormulaAndFunctionMetricDataSource.md)
 - [FormulaAndFunctionMetricQueryDefinition](FormulaAndFunctionMetricQueryDefinition.md)
 - [FormulaAndFunctionProcessQueryDataSource](FormulaAndFunctionProcessQueryDataSource.md)
 - [FormulaAndFunctionProcessQueryDefinition](FormulaAndFunctionProcessQueryDefinition.md)
 - [FormulaAndFunctionQueryDefinition](FormulaAndFunctionQueryDefinition.md)
 - [FormulaAndFunctionResponseFormat](FormulaAndFunctionResponseFormat.md)
 - [FreeTextWidgetDefinition](FreeTextWidgetDefinition.md)
 - [FreeTextWidgetDefinitionType](FreeTextWidgetDefinitionType.md)
 - [GCPAccount](GCPAccount.md)
 - [GCPAccountListResponse](GCPAccountListResponse.md)
 - [GeomapWidgetDefinition](GeomapWidgetDefinition.md)
 - [GeomapWidgetDefinitionStyle](GeomapWidgetDefinitionStyle.md)
 - [GeomapWidgetDefinitionType](GeomapWidgetDefinitionType.md)
 - [GeomapWidgetDefinitionView](GeomapWidgetDefinitionView.md)
 - [GeomapWidgetRequest](GeomapWidgetRequest.md)
 - [GraphSnapshot](GraphSnapshot.md)
 - [GroupWidgetDefinition](GroupWidgetDefinition.md)
 - [GroupWidgetDefinitionType](GroupWidgetDefinitionType.md)
 - [HTTPMethod](HTTPMethod.md)
 - [HeatMapWidgetDefinition](HeatMapWidgetDefinition.md)
 - [HeatMapWidgetDefinitionType](HeatMapWidgetDefinitionType.md)
 - [HeatMapWidgetRequest](HeatMapWidgetRequest.md)
 - [Host](Host.md)
 - [HostListResponse](HostListResponse.md)
 - [HostMapRequest](HostMapRequest.md)
 - [HostMapWidgetDefinition](HostMapWidgetDefinition.md)
 - [HostMapWidgetDefinitionRequests](HostMapWidgetDefinitionRequests.md)
 - [HostMapWidgetDefinitionStyle](HostMapWidgetDefinitionStyle.md)
 - [HostMapWidgetDefinitionType](HostMapWidgetDefinitionType.md)
 - [HostMeta](HostMeta.md)
 - [HostMetrics](HostMetrics.md)
 - [HostMuteResponse](HostMuteResponse.md)
 - [HostMuteSettings](HostMuteSettings.md)
 - [HostTags](HostTags.md)
 - [HostTotals](HostTotals.md)
 - [IFrameWidgetDefinition](IFrameWidgetDefinition.md)
 - [IFrameWidgetDefinitionType](IFrameWidgetDefinitionType.md)
 - [IPPrefixesAPI](IPPrefixesAPI.md)
 - [IPPrefixesAPM](IPPrefixesAPM.md)
 - [IPPrefixesAgents](IPPrefixesAgents.md)
 - [IPPrefixesLogs](IPPrefixesLogs.md)
 - [IPPrefixesProcess](IPPrefixesProcess.md)
 - [IPPrefixesSynthetics](IPPrefixesSynthetics.md)
 - [IPPrefixesWebhooks](IPPrefixesWebhooks.md)
 - [IPRanges](IPRanges.md)
 - [IdpFormData](IdpFormData.md)
 - [IdpResponse](IdpResponse.md)
 - [ImageWidgetDefinition](ImageWidgetDefinition.md)
 - [ImageWidgetDefinitionType](ImageWidgetDefinitionType.md)
 - [Log](Log.md)
 - [LogContent](LogContent.md)
 - [LogQueryDefinition](LogQueryDefinition.md)
 - [LogQueryDefinitionGroupBy](LogQueryDefinitionGroupBy.md)
 - [LogQueryDefinitionGroupBySort](LogQueryDefinitionGroupBySort.md)
 - [LogQueryDefinitionSearch](LogQueryDefinitionSearch.md)
 - [LogStreamWidgetDefinition](LogStreamWidgetDefinition.md)
 - [LogStreamWidgetDefinitionType](LogStreamWidgetDefinitionType.md)
 - [LogsAPIError](LogsAPIError.md)
 - [LogsAPIErrorResponse](LogsAPIErrorResponse.md)
 - [LogsArithmeticProcessor](LogsArithmeticProcessor.md)
 - [LogsArithmeticProcessorType](LogsArithmeticProcessorType.md)
 - [LogsAttributeRemapper](LogsAttributeRemapper.md)
 - [LogsAttributeRemapperType](LogsAttributeRemapperType.md)
 - [LogsCategoryProcessor](LogsCategoryProcessor.md)
 - [LogsCategoryProcessorCategory](LogsCategoryProcessorCategory.md)
 - [LogsCategoryProcessorType](LogsCategoryProcessorType.md)
 - [LogsDateRemapper](LogsDateRemapper.md)
 - [LogsDateRemapperType](LogsDateRemapperType.md)
 - [LogsExclusion](LogsExclusion.md)
 - [LogsExclusionFilter](LogsExclusionFilter.md)
 - [LogsFilter](LogsFilter.md)
 - [LogsGeoIPParser](LogsGeoIPParser.md)
 - [LogsGeoIPParserType](LogsGeoIPParserType.md)
 - [LogsGrokParser](LogsGrokParser.md)
 - [LogsGrokParserRules](LogsGrokParserRules.md)
 - [LogsGrokParserType](LogsGrokParserType.md)
 - [LogsIndex](LogsIndex.md)
 - [LogsIndexListResponse](LogsIndexListResponse.md)
 - [LogsIndexUpdateRequest](LogsIndexUpdateRequest.md)
 - [LogsIndexesOrder](LogsIndexesOrder.md)
 - [LogsListRequest](LogsListRequest.md)
 - [LogsListRequestTime](LogsListRequestTime.md)
 - [LogsListResponse](LogsListResponse.md)
 - [LogsLookupProcessor](LogsLookupProcessor.md)
 - [LogsLookupProcessorType](LogsLookupProcessorType.md)
 - [LogsMessageRemapper](LogsMessageRemapper.md)
 - [LogsMessageRemapperType](LogsMessageRemapperType.md)
 - [LogsPipeline](LogsPipeline.md)
 - [LogsPipelineList](LogsPipelineList.md)
 - [LogsPipelineProcessor](LogsPipelineProcessor.md)
 - [LogsPipelineProcessorType](LogsPipelineProcessorType.md)
 - [LogsPipelinesOrder](LogsPipelinesOrder.md)
 - [LogsProcessor](LogsProcessor.md)
 - [LogsQueryCompute](LogsQueryCompute.md)
 - [LogsServiceRemapper](LogsServiceRemapper.md)
 - [LogsServiceRemapperType](LogsServiceRemapperType.md)
 - [LogsSort](LogsSort.md)
 - [LogsStatusRemapper](LogsStatusRemapper.md)
 - [LogsStatusRemapperType](LogsStatusRemapperType.md)
 - [LogsStringBuilderProcessor](LogsStringBuilderProcessor.md)
 - [LogsStringBuilderProcessorType](LogsStringBuilderProcessorType.md)
 - [LogsTraceRemapper](LogsTraceRemapper.md)
 - [LogsTraceRemapperType](LogsTraceRemapperType.md)
 - [LogsURLParser](LogsURLParser.md)
 - [LogsURLParserType](LogsURLParserType.md)
 - [LogsUserAgentParser](LogsUserAgentParser.md)
 - [LogsUserAgentParserType](LogsUserAgentParserType.md)
 - [MetricMetadata](MetricMetadata.md)
 - [MetricSearchResponse](MetricSearchResponse.md)
 - [MetricSearchResponseResults](MetricSearchResponseResults.md)
 - [MetricsListResponse](MetricsListResponse.md)
 - [MetricsQueryMetadata](MetricsQueryMetadata.md)
 - [MetricsQueryResponse](MetricsQueryResponse.md)
 - [MetricsQueryUnit](MetricsQueryUnit.md)
 - [Monitor](Monitor.md)
 - [MonitorDeviceID](MonitorDeviceID.md)
 - [MonitorOptions](MonitorOptions.md)
 - [MonitorOptionsAggregation](MonitorOptionsAggregation.md)
 - [MonitorOverallStates](MonitorOverallStates.md)
 - [MonitorState](MonitorState.md)
 - [MonitorStateGroup](MonitorStateGroup.md)
 - [MonitorSummaryWidgetDefinition](MonitorSummaryWidgetDefinition.md)
 - [MonitorSummaryWidgetDefinitionType](MonitorSummaryWidgetDefinitionType.md)
 - [MonitorThresholdWindowOptions](MonitorThresholdWindowOptions.md)
 - [MonitorThresholds](MonitorThresholds.md)
 - [MonitorType](MonitorType.md)
 - [MonitorUpdateRequest](MonitorUpdateRequest.md)
 - [NoteWidgetDefinition](NoteWidgetDefinition.md)
 - [NoteWidgetDefinitionType](NoteWidgetDefinitionType.md)
 - [Organization](Organization.md)
 - [OrganizationBilling](OrganizationBilling.md)
 - [OrganizationCreateBody](OrganizationCreateBody.md)
 - [OrganizationCreateResponse](OrganizationCreateResponse.md)
 - [OrganizationListResponse](OrganizationListResponse.md)
 - [OrganizationResponse](OrganizationResponse.md)
 - [OrganizationSettings](OrganizationSettings.md)
 - [OrganizationSettingsSaml](OrganizationSettingsSaml.md)
 - [OrganizationSettingsSamlAutocreateUsersDomains](OrganizationSettingsSamlAutocreateUsersDomains.md)
 - [OrganizationSettingsSamlIdpInitiatedLogin](OrganizationSettingsSamlIdpInitiatedLogin.md)
 - [OrganizationSettingsSamlStrictMode](OrganizationSettingsSamlStrictMode.md)
 - [OrganizationSubscription](OrganizationSubscription.md)
 - [PagerDutyService](PagerDutyService.md)
 - [PagerDutyServiceKey](PagerDutyServiceKey.md)
 - [PagerDutyServiceName](PagerDutyServiceName.md)
 - [Point](Point.md)
 - [ProcessQueryDefinition](ProcessQueryDefinition.md)
 - [QuerySortOrder](QuerySortOrder.md)
 - [QueryValueWidgetDefinition](QueryValueWidgetDefinition.md)
 - [QueryValueWidgetDefinitionType](QueryValueWidgetDefinitionType.md)
 - [QueryValueWidgetRequest](QueryValueWidgetRequest.md)
 - [SLOBulkDelete](SLOBulkDelete.md)
 - [SLOBulkDeleteError](SLOBulkDeleteError.md)
 - [SLOBulkDeleteResponse](SLOBulkDeleteResponse.md)
 - [SLOBulkDeleteResponseData](SLOBulkDeleteResponseData.md)
 - [SLOCorrection](SLOCorrection.md)
 - [SLOCorrectionCategory](SLOCorrectionCategory.md)
 - [SLOCorrectionCreateData](SLOCorrectionCreateData.md)
 - [SLOCorrectionCreateRequest](SLOCorrectionCreateRequest.md)
 - [SLOCorrectionCreateRequestAttributes](SLOCorrectionCreateRequestAttributes.md)
 - [SLOCorrectionListResponse](SLOCorrectionListResponse.md)
 - [SLOCorrectionResponse](SLOCorrectionResponse.md)
 - [SLOCorrectionResponseAttributes](SLOCorrectionResponseAttributes.md)
 - [SLOCorrectionType](SLOCorrectionType.md)
 - [SLOCorrectionUpdateData](SLOCorrectionUpdateData.md)
 - [SLOCorrectionUpdateRequest](SLOCorrectionUpdateRequest.md)
 - [SLOCorrectionUpdateRequestAttributes](SLOCorrectionUpdateRequestAttributes.md)
 - [SLODeleteResponse](SLODeleteResponse.md)
 - [SLOErrorBudgetRemainingData](SLOErrorBudgetRemainingData.md)
 - [SLOErrorTimeframe](SLOErrorTimeframe.md)
 - [SLOHistoryMetrics](SLOHistoryMetrics.md)
 - [SLOHistoryMetricsSeries](SLOHistoryMetricsSeries.md)
 - [SLOHistoryMetricsSeriesMetadata](SLOHistoryMetricsSeriesMetadata.md)
 - [SLOHistoryMetricsSeriesMetadataUnit](SLOHistoryMetricsSeriesMetadataUnit.md)
 - [SLOHistoryResponse](SLOHistoryResponse.md)
 - [SLOHistoryResponseData](SLOHistoryResponseData.md)
 - [SLOHistoryResponseError](SLOHistoryResponseError.md)
 - [SLOHistorySLIData](SLOHistorySLIData.md)
 - [SLOListResponse](SLOListResponse.md)
 - [SLOResponse](SLOResponse.md)
 - [SLOThreshold](SLOThreshold.md)
 - [SLOTimeframe](SLOTimeframe.md)
 - [SLOType](SLOType.md)
 - [SLOTypeNumeric](SLOTypeNumeric.md)
 - [SLOWidgetDefinition](SLOWidgetDefinition.md)
 - [SLOWidgetDefinitionType](SLOWidgetDefinitionType.md)
 - [ScatterPlotRequest](ScatterPlotRequest.md)
 - [ScatterPlotWidgetDefinition](ScatterPlotWidgetDefinition.md)
 - [ScatterPlotWidgetDefinitionRequests](ScatterPlotWidgetDefinitionRequests.md)
 - [ScatterPlotWidgetDefinitionType](ScatterPlotWidgetDefinitionType.md)
 - [ServiceLevelObjective](ServiceLevelObjective.md)
 - [ServiceLevelObjectiveQuery](ServiceLevelObjectiveQuery.md)
 - [ServiceLevelObjectiveRequest](ServiceLevelObjectiveRequest.md)
 - [ServiceMapWidgetDefinition](ServiceMapWidgetDefinition.md)
 - [ServiceMapWidgetDefinitionType](ServiceMapWidgetDefinitionType.md)
 - [ServiceSummaryWidgetDefinition](ServiceSummaryWidgetDefinition.md)
 - [ServiceSummaryWidgetDefinitionType](ServiceSummaryWidgetDefinitionType.md)
 - [SlackIntegrationChannel](SlackIntegrationChannel.md)
 - [SlackIntegrationChannelDisplay](SlackIntegrationChannelDisplay.md)
 - [SlackIntegrationChannels](SlackIntegrationChannels.md)
 - [SyntheticsAPIStep](SyntheticsAPIStep.md)
 - [SyntheticsAPIStepSubtype](SyntheticsAPIStepSubtype.md)
 - [SyntheticsAPITest](SyntheticsAPITest.md)
 - [SyntheticsAPITestConfig](SyntheticsAPITestConfig.md)
 - [SyntheticsAPITestResultData](SyntheticsAPITestResultData.md)
 - [SyntheticsAPITestResultFull](SyntheticsAPITestResultFull.md)
 - [SyntheticsAPITestResultFullCheck](SyntheticsAPITestResultFullCheck.md)
 - [SyntheticsAPITestResultShort](SyntheticsAPITestResultShort.md)
 - [SyntheticsAPITestResultShortResult](SyntheticsAPITestResultShortResult.md)
 - [SyntheticsAPITestType](SyntheticsAPITestType.md)
 - [SyntheticsAssertion](SyntheticsAssertion.md)
 - [SyntheticsAssertionJSONPathOperator](SyntheticsAssertionJSONPathOperator.md)
 - [SyntheticsAssertionJSONPathTarget](SyntheticsAssertionJSONPathTarget.md)
 - [SyntheticsAssertionJSONPathTargetTarget](SyntheticsAssertionJSONPathTargetTarget.md)
 - [SyntheticsAssertionOperator](SyntheticsAssertionOperator.md)
 - [SyntheticsAssertionTarget](SyntheticsAssertionTarget.md)
 - [SyntheticsAssertionType](SyntheticsAssertionType.md)
 - [SyntheticsBasicAuth](SyntheticsBasicAuth.md)
 - [SyntheticsBrowserError](SyntheticsBrowserError.md)
 - [SyntheticsBrowserErrorType](SyntheticsBrowserErrorType.md)
 - [SyntheticsBrowserTest](SyntheticsBrowserTest.md)
 - [SyntheticsBrowserTestConfig](SyntheticsBrowserTestConfig.md)
 - [SyntheticsBrowserTestResultData](SyntheticsBrowserTestResultData.md)
 - [SyntheticsBrowserTestResultFull](SyntheticsBrowserTestResultFull.md)
 - [SyntheticsBrowserTestResultFullCheck](SyntheticsBrowserTestResultFullCheck.md)
 - [SyntheticsBrowserTestResultShort](SyntheticsBrowserTestResultShort.md)
 - [SyntheticsBrowserTestResultShortResult](SyntheticsBrowserTestResultShortResult.md)
 - [SyntheticsBrowserTestType](SyntheticsBrowserTestType.md)
 - [SyntheticsBrowserVariable](SyntheticsBrowserVariable.md)
 - [SyntheticsBrowserVariableType](SyntheticsBrowserVariableType.md)
 - [SyntheticsCITest](SyntheticsCITest.md)
 - [SyntheticsCITestBody](SyntheticsCITestBody.md)
 - [SyntheticsCITestMetadata](SyntheticsCITestMetadata.md)
 - [SyntheticsCITestMetadataCi](SyntheticsCITestMetadataCi.md)
 - [SyntheticsCITestMetadataGit](SyntheticsCITestMetadataGit.md)
 - [SyntheticsCheckType](SyntheticsCheckType.md)
 - [SyntheticsConfigVariable](SyntheticsConfigVariable.md)
 - [SyntheticsConfigVariableType](SyntheticsConfigVariableType.md)
 - [SyntheticsCoreWebVitals](SyntheticsCoreWebVitals.md)
 - [SyntheticsDeleteTestsPayload](SyntheticsDeleteTestsPayload.md)
 - [SyntheticsDeleteTestsResponse](SyntheticsDeleteTestsResponse.md)
 - [SyntheticsDeletedTest](SyntheticsDeletedTest.md)
 - [SyntheticsDevice](SyntheticsDevice.md)
 - [SyntheticsDeviceID](SyntheticsDeviceID.md)
 - [SyntheticsErrorCode](SyntheticsErrorCode.md)
 - [SyntheticsGetAPITestLatestResultsResponse](SyntheticsGetAPITestLatestResultsResponse.md)
 - [SyntheticsGetBrowserTestLatestResultsResponse](SyntheticsGetBrowserTestLatestResultsResponse.md)
 - [SyntheticsGlobalVariable](SyntheticsGlobalVariable.md)
 - [SyntheticsGlobalVariableParseTestOptions](SyntheticsGlobalVariableParseTestOptions.md)
 - [SyntheticsGlobalVariableParseTestOptionsType](SyntheticsGlobalVariableParseTestOptionsType.md)
 - [SyntheticsGlobalVariableParserType](SyntheticsGlobalVariableParserType.md)
 - [SyntheticsGlobalVariableValue](SyntheticsGlobalVariableValue.md)
 - [SyntheticsListTestsResponse](SyntheticsListTestsResponse.md)
 - [SyntheticsLocation](SyntheticsLocation.md)
 - [SyntheticsLocations](SyntheticsLocations.md)
 - [SyntheticsParsingOptions](SyntheticsParsingOptions.md)
 - [SyntheticsPlayingTab](SyntheticsPlayingTab.md)
 - [SyntheticsPrivateLocation](SyntheticsPrivateLocation.md)
 - [SyntheticsPrivateLocationCreationResponse](SyntheticsPrivateLocationCreationResponse.md)
 - [SyntheticsPrivateLocationCreationResponseResultEncryption](SyntheticsPrivateLocationCreationResponseResultEncryption.md)
 - [SyntheticsPrivateLocationSecrets](SyntheticsPrivateLocationSecrets.md)
 - [SyntheticsPrivateLocationSecretsAuthentication](SyntheticsPrivateLocationSecretsAuthentication.md)
 - [SyntheticsPrivateLocationSecretsConfigDecryption](SyntheticsPrivateLocationSecretsConfigDecryption.md)
 - [SyntheticsSSLCertificate](SyntheticsSSLCertificate.md)
 - [SyntheticsSSLCertificateIssuer](SyntheticsSSLCertificateIssuer.md)
 - [SyntheticsSSLCertificateSubject](SyntheticsSSLCertificateSubject.md)
 - [SyntheticsStep](SyntheticsStep.md)
 - [SyntheticsStepDetail](SyntheticsStepDetail.md)
 - [SyntheticsStepDetailWarning](SyntheticsStepDetailWarning.md)
 - [SyntheticsStepType](SyntheticsStepType.md)
 - [SyntheticsTestConfig](SyntheticsTestConfig.md)
 - [SyntheticsTestDetails](SyntheticsTestDetails.md)
 - [SyntheticsTestDetailsSubType](SyntheticsTestDetailsSubType.md)
 - [SyntheticsTestDetailsType](SyntheticsTestDetailsType.md)
 - [SyntheticsTestHeaders](SyntheticsTestHeaders.md)
 - [SyntheticsTestMonitorStatus](SyntheticsTestMonitorStatus.md)
 - [SyntheticsTestOptions](SyntheticsTestOptions.md)
 - [SyntheticsTestOptionsMonitorOptions](SyntheticsTestOptionsMonitorOptions.md)
 - [SyntheticsTestOptionsRetry](SyntheticsTestOptionsRetry.md)
 - [SyntheticsTestPauseStatus](SyntheticsTestPauseStatus.md)
 - [SyntheticsTestProcessStatus](SyntheticsTestProcessStatus.md)
 - [SyntheticsTestRequest](SyntheticsTestRequest.md)
 - [SyntheticsTestRequestCertificate](SyntheticsTestRequestCertificate.md)
 - [SyntheticsTestRequestCertificateItem](SyntheticsTestRequestCertificateItem.md)
 - [SyntheticsTickInterval](SyntheticsTickInterval.md)
 - [SyntheticsTiming](SyntheticsTiming.md)
 - [SyntheticsTriggerCITestLocation](SyntheticsTriggerCITestLocation.md)
 - [SyntheticsTriggerCITestRunResult](SyntheticsTriggerCITestRunResult.md)
 - [SyntheticsTriggerCITestsResponse](SyntheticsTriggerCITestsResponse.md)
 - [SyntheticsUpdateTestPauseStatusPayload](SyntheticsUpdateTestPauseStatusPayload.md)
 - [SyntheticsVariableParser](SyntheticsVariableParser.md)
 - [SyntheticsWarningType](SyntheticsWarningType.md)
 - [TableWidgetCellDisplayMode](TableWidgetCellDisplayMode.md)
 - [TableWidgetDefinition](TableWidgetDefinition.md)
 - [TableWidgetDefinitionType](TableWidgetDefinitionType.md)
 - [TableWidgetHasSearchBar](TableWidgetHasSearchBar.md)
 - [TableWidgetRequest](TableWidgetRequest.md)
 - [TagToHosts](TagToHosts.md)
 - [TargetFormatType](TargetFormatType.md)
 - [TimeseriesWidgetDefinition](TimeseriesWidgetDefinition.md)
 - [TimeseriesWidgetDefinitionType](TimeseriesWidgetDefinitionType.md)
 - [TimeseriesWidgetExpressionAlias](TimeseriesWidgetExpressionAlias.md)
 - [TimeseriesWidgetLegendColumn](TimeseriesWidgetLegendColumn.md)
 - [TimeseriesWidgetLegendLayout](TimeseriesWidgetLegendLayout.md)
 - [TimeseriesWidgetRequest](TimeseriesWidgetRequest.md)
 - [ToplistWidgetDefinition](ToplistWidgetDefinition.md)
 - [ToplistWidgetDefinitionType](ToplistWidgetDefinitionType.md)
 - [ToplistWidgetRequest](ToplistWidgetRequest.md)
 - [UsageAnalyzedLogsHour](UsageAnalyzedLogsHour.md)
 - [UsageAnalyzedLogsResponse](UsageAnalyzedLogsResponse.md)
 - [UsageAttributionAggregates](UsageAttributionAggregates.md)
 - [UsageAttributionAggregatesBody](UsageAttributionAggregatesBody.md)
 - [UsageAttributionBody](UsageAttributionBody.md)
 - [UsageAttributionMetadata](UsageAttributionMetadata.md)
 - [UsageAttributionPagination](UsageAttributionPagination.md)
 - [UsageAttributionResponse](UsageAttributionResponse.md)
 - [UsageAttributionSort](UsageAttributionSort.md)
 - [UsageAttributionTagNames](UsageAttributionTagNames.md)
 - [UsageAttributionValues](UsageAttributionValues.md)
 - [UsageBillableSummaryBody](UsageBillableSummaryBody.md)
 - [UsageBillableSummaryHour](UsageBillableSummaryHour.md)
 - [UsageBillableSummaryKeys](UsageBillableSummaryKeys.md)
 - [UsageBillableSummaryResponse](UsageBillableSummaryResponse.md)
 - [UsageCustomReportsAttributes](UsageCustomReportsAttributes.md)
 - [UsageCustomReportsData](UsageCustomReportsData.md)
 - [UsageCustomReportsMeta](UsageCustomReportsMeta.md)
 - [UsageCustomReportsPage](UsageCustomReportsPage.md)
 - [UsageCustomReportsResponse](UsageCustomReportsResponse.md)
 - [UsageFargateHour](UsageFargateHour.md)
 - [UsageFargateResponse](UsageFargateResponse.md)
 - [UsageHostHour](UsageHostHour.md)
 - [UsageHostsResponse](UsageHostsResponse.md)
 - [UsageIncidentManagementHour](UsageIncidentManagementHour.md)
 - [UsageIncidentManagementResponse](UsageIncidentManagementResponse.md)
 - [UsageIndexedSpansHour](UsageIndexedSpansHour.md)
 - [UsageIndexedSpansResponse](UsageIndexedSpansResponse.md)
 - [UsageIngestedSpansHour](UsageIngestedSpansHour.md)
 - [UsageIngestedSpansResponse](UsageIngestedSpansResponse.md)
 - [UsageIoTHour](UsageIoTHour.md)
 - [UsageIoTResponse](UsageIoTResponse.md)
 - [UsageLambdaHour](UsageLambdaHour.md)
 - [UsageLambdaResponse](UsageLambdaResponse.md)
 - [UsageLogsByIndexHour](UsageLogsByIndexHour.md)
 - [UsageLogsByIndexResponse](UsageLogsByIndexResponse.md)
 - [UsageLogsHour](UsageLogsHour.md)
 - [UsageLogsResponse](UsageLogsResponse.md)
 - [UsageMetricCategory](UsageMetricCategory.md)
 - [UsageNetworkFlowsHour](UsageNetworkFlowsHour.md)
 - [UsageNetworkFlowsResponse](UsageNetworkFlowsResponse.md)
 - [UsageNetworkHostsHour](UsageNetworkHostsHour.md)
 - [UsageNetworkHostsResponse](UsageNetworkHostsResponse.md)
 - [UsageProfilingHour](UsageProfilingHour.md)
 - [UsageProfilingResponse](UsageProfilingResponse.md)
 - [UsageReportsType](UsageReportsType.md)
 - [UsageRumSessionsHour](UsageRumSessionsHour.md)
 - [UsageRumSessionsResponse](UsageRumSessionsResponse.md)
 - [UsageSNMPHour](UsageSNMPHour.md)
 - [UsageSNMPResponse](UsageSNMPResponse.md)
 - [UsageSort](UsageSort.md)
 - [UsageSortDirection](UsageSortDirection.md)
 - [UsageSpecifiedCustomReportsAttributes](UsageSpecifiedCustomReportsAttributes.md)
 - [UsageSpecifiedCustomReportsData](UsageSpecifiedCustomReportsData.md)
 - [UsageSpecifiedCustomReportsMeta](UsageSpecifiedCustomReportsMeta.md)
 - [UsageSpecifiedCustomReportsPage](UsageSpecifiedCustomReportsPage.md)
 - [UsageSpecifiedCustomReportsResponse](UsageSpecifiedCustomReportsResponse.md)
 - [UsageSummaryDate](UsageSummaryDate.md)
 - [UsageSummaryDateOrg](UsageSummaryDateOrg.md)
 - [UsageSummaryResponse](UsageSummaryResponse.md)
 - [UsageSyntheticsAPIHour](UsageSyntheticsAPIHour.md)
 - [UsageSyntheticsAPIResponse](UsageSyntheticsAPIResponse.md)
 - [UsageSyntheticsBrowserHour](UsageSyntheticsBrowserHour.md)
 - [UsageSyntheticsBrowserResponse](UsageSyntheticsBrowserResponse.md)
 - [UsageSyntheticsHour](UsageSyntheticsHour.md)
 - [UsageSyntheticsResponse](UsageSyntheticsResponse.md)
 - [UsageTimeseriesHour](UsageTimeseriesHour.md)
 - [UsageTimeseriesResponse](UsageTimeseriesResponse.md)
 - [UsageTopAvgMetricsHour](UsageTopAvgMetricsHour.md)
 - [UsageTopAvgMetricsResponse](UsageTopAvgMetricsResponse.md)
 - [UsageTraceHour](UsageTraceHour.md)
 - [UsageTraceResponse](UsageTraceResponse.md)
 - [UsageTracingWithoutLimitsHour](UsageTracingWithoutLimitsHour.md)
 - [UsageTracingWithoutLimitsResponse](UsageTracingWithoutLimitsResponse.md)
 - [User](User.md)
 - [UserDisableResponse](UserDisableResponse.md)
 - [UserListResponse](UserListResponse.md)
 - [UserResponse](UserResponse.md)
 - [Widget](Widget.md)
 - [WidgetAggregator](WidgetAggregator.md)
 - [WidgetAxis](WidgetAxis.md)
 - [WidgetChangeType](WidgetChangeType.md)
 - [WidgetColorPreference](WidgetColorPreference.md)
 - [WidgetComparator](WidgetComparator.md)
 - [WidgetCompareTo](WidgetCompareTo.md)
 - [WidgetConditionalFormat](WidgetConditionalFormat.md)
 - [WidgetCustomLink](WidgetCustomLink.md)
 - [WidgetDefinition](WidgetDefinition.md)
 - [WidgetDisplayType](WidgetDisplayType.md)
 - [WidgetEvent](WidgetEvent.md)
 - [WidgetEventSize](WidgetEventSize.md)
 - [WidgetFieldSort](WidgetFieldSort.md)
 - [WidgetFormula](WidgetFormula.md)
 - [WidgetFormulaLimit](WidgetFormulaLimit.md)
 - [WidgetGrouping](WidgetGrouping.md)
 - [WidgetImageSizing](WidgetImageSizing.md)
 - [WidgetLayout](WidgetLayout.md)
 - [WidgetLayoutType](WidgetLayoutType.md)
 - [WidgetLineType](WidgetLineType.md)
 - [WidgetLineWidth](WidgetLineWidth.md)
 - [WidgetLiveSpan](WidgetLiveSpan.md)
 - [WidgetMargin](WidgetMargin.md)
 - [WidgetMarker](WidgetMarker.md)
 - [WidgetMessageDisplay](WidgetMessageDisplay.md)
 - [WidgetMonitorSummaryDisplayFormat](WidgetMonitorSummaryDisplayFormat.md)
 - [WidgetMonitorSummarySort](WidgetMonitorSummarySort.md)
 - [WidgetNodeType](WidgetNodeType.md)
 - [WidgetOrderBy](WidgetOrderBy.md)
 - [WidgetPalette](WidgetPalette.md)
 - [WidgetRequestStyle](WidgetRequestStyle.md)
 - [WidgetServiceSummaryDisplayFormat](WidgetServiceSummaryDisplayFormat.md)
 - [WidgetSizeFormat](WidgetSizeFormat.md)
 - [WidgetSort](WidgetSort.md)
 - [WidgetStyle](WidgetStyle.md)
 - [WidgetSummaryType](WidgetSummaryType.md)
 - [WidgetTextAlign](WidgetTextAlign.md)
 - [WidgetTickEdge](WidgetTickEdge.md)
 - [WidgetTime](WidgetTime.md)
 - [WidgetTimeWindows](WidgetTimeWindows.md)
 - [WidgetViewMode](WidgetViewMode.md)
 - [WidgetVizType](WidgetVizType.md)


## Documentation For Authorization


## apiKeyAuth

- **Type**: API key
- **API key parameter name**: DD-API-KEY
- **Location**: HTTP header


## apiKeyAuthQuery

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: URL query string


## appKeyAuth

- **Type**: API key
- **API key parameter name**: DD-APPLICATION-KEY
- **Location**: HTTP header


## appKeyAuthQuery

- **Type**: API key
- **API key parameter name**: application_key
- **Location**: URL query string


## Author

support@datadoghq.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in datadog_api_client.v1.apis and datadog_api_client.v1.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from datadog_api_client.v1.api.default_api import DefaultApi`
- `from datadog_api_client.v1.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import datadog_api_client.v1
from datadog_api_client.v1.apis import *
from datadog_api_client.v1.models import *
```

