# datadog-api-client.v2
Collection of all Datadog Public endpoints.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.datadoghq.com/support/](https://www.datadoghq.com/support/)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/DataDog/datadog-api-client-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/DataDog/datadog-api-client-python.git`)

Then import the package:
```python
import datadog_api_client.v2
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import datadog_api_client.v2
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import datadog_api_client.v2
from pprint import pprint
from datadog_api_client.v2.api import dashboard_lists_api
from datadog_api_client.v2.model.api_error_response import APIErrorResponse
from datadog_api_client.v2.model.dashboard_list_add_items_request import DashboardListAddItemsRequest
from datadog_api_client.v2.model.dashboard_list_add_items_response import DashboardListAddItemsResponse
from datadog_api_client.v2.model.dashboard_list_delete_items_request import DashboardListDeleteItemsRequest
from datadog_api_client.v2.model.dashboard_list_delete_items_response import DashboardListDeleteItemsResponse
from datadog_api_client.v2.model.dashboard_list_items import DashboardListItems
from datadog_api_client.v2.model.dashboard_list_update_items_request import DashboardListUpdateItemsRequest
from datadog_api_client.v2.model.dashboard_list_update_items_response import DashboardListUpdateItemsResponse
# See configuration.py for a list of all supported configuration parameters.
configuration = Configuration()

# Defining the site is optional and defaults to datadoghq.com
if "DD_SITE" in os.environ:
    configuration.server_variables["site"] = os.environ["DD_SITE"]

# Configure API key authorization: apiKeyAuth
configuration.api_key['apiKeyAuth'] = os.getenv('DD_CLIENT_API_KEY')

# Configure API key authorization: appKeyAuth
configuration.api_key['appKeyAuth'] = os.getenv('DD_CLIENT_APP_KEY')


# Enter a context with an instance of the API client
with datadog_api_client.v2.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = dashboard_lists_api.DashboardListsApi(api_client)
    dashboard_list_id = 1 # int | ID of the dashboard list to add items to.
body = DashboardListAddItemsRequest(
        dashboards=[
            DashboardListItemRequest(
                id="q5j-nti-fv6",
                type=DashboardType("custom_timeboard"),
            ),
        ],
    ) # DashboardListAddItemsRequest | Dashboards to add to the dashboard list.

    try:
        # Add Items to a Dashboard List
        api_response = api_instance.create_dashboard_list_items(dashboard_list_id, body)
        pprint(api_response)
    except datadog_api_client.v2.ApiException as e:
        print("Exception when calling DashboardListsApi->create_dashboard_list_items: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.datadoghq.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DashboardListsApi* | [**create_dashboard_list_items**](DashboardListsApi.md#create_dashboard_list_items) | **POST** /api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards | Add Items to a Dashboard List
*DashboardListsApi* | [**delete_dashboard_list_items**](DashboardListsApi.md#delete_dashboard_list_items) | **DELETE** /api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards | Delete items from a dashboard list
*DashboardListsApi* | [**get_dashboard_list_items**](DashboardListsApi.md#get_dashboard_list_items) | **GET** /api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards | Get items of a Dashboard List
*DashboardListsApi* | [**update_dashboard_list_items**](DashboardListsApi.md#update_dashboard_list_items) | **PUT** /api/v2/dashboard/lists/manual/{dashboard_list_id}/dashboards | Update items of a dashboard list
*IncidentServicesApi* | [**create_incident_service**](IncidentServicesApi.md#create_incident_service) | **POST** /api/v2/services | Create a new incident service
*IncidentServicesApi* | [**delete_incident_service**](IncidentServicesApi.md#delete_incident_service) | **DELETE** /api/v2/services/{service_id} | Delete an existing incident service
*IncidentServicesApi* | [**get_incident_service**](IncidentServicesApi.md#get_incident_service) | **GET** /api/v2/services/{service_id} | Get details of an incident service
*IncidentServicesApi* | [**list_incident_services**](IncidentServicesApi.md#list_incident_services) | **GET** /api/v2/services | Get a list of all incident services
*IncidentServicesApi* | [**update_incident_service**](IncidentServicesApi.md#update_incident_service) | **PATCH** /api/v2/services/{service_id} | Update an existing incident service
*IncidentTeamsApi* | [**create_incident_team**](IncidentTeamsApi.md#create_incident_team) | **POST** /api/v2/teams | Create a new incident team
*IncidentTeamsApi* | [**delete_incident_team**](IncidentTeamsApi.md#delete_incident_team) | **DELETE** /api/v2/teams/{team_id} | Delete an existing incident team
*IncidentTeamsApi* | [**get_incident_team**](IncidentTeamsApi.md#get_incident_team) | **GET** /api/v2/teams/{team_id} | Get details of an incident team
*IncidentTeamsApi* | [**list_incident_teams**](IncidentTeamsApi.md#list_incident_teams) | **GET** /api/v2/teams | Get a list of all incident teams
*IncidentTeamsApi* | [**update_incident_team**](IncidentTeamsApi.md#update_incident_team) | **PATCH** /api/v2/teams/{team_id} | Update an existing incident team
*IncidentsApi* | [**create_incident**](IncidentsApi.md#create_incident) | **POST** /api/v2/incidents | Create an incident
*IncidentsApi* | [**delete_incident**](IncidentsApi.md#delete_incident) | **DELETE** /api/v2/incidents/{incident_id} | Delete an existing incident
*IncidentsApi* | [**get_incident**](IncidentsApi.md#get_incident) | **GET** /api/v2/incidents/{incident_id} | Get the details of an incident
*IncidentsApi* | [**list_incidents**](IncidentsApi.md#list_incidents) | **GET** /api/v2/incidents | Get a list of incidents
*IncidentsApi* | [**update_incident**](IncidentsApi.md#update_incident) | **PATCH** /api/v2/incidents/{incident_id} | Update an existing incident
*KeyManagementApi* | [**create_api_key**](KeyManagementApi.md#create_api_key) | **POST** /api/v2/api_keys | Create an API key
*KeyManagementApi* | [**create_current_user_application_key**](KeyManagementApi.md#create_current_user_application_key) | **POST** /api/v2/current_user/application_keys | Create an application key for current user
*KeyManagementApi* | [**delete_api_key**](KeyManagementApi.md#delete_api_key) | **DELETE** /api/v2/api_keys/{api_key_id} | Delete an API key
*KeyManagementApi* | [**delete_application_key**](KeyManagementApi.md#delete_application_key) | **DELETE** /api/v2/application_keys/{app_key_id} | Delete an application key
*KeyManagementApi* | [**delete_current_user_application_key**](KeyManagementApi.md#delete_current_user_application_key) | **DELETE** /api/v2/current_user/application_keys/{app_key_id} | Delete an application key owned by current user
*KeyManagementApi* | [**get_api_key**](KeyManagementApi.md#get_api_key) | **GET** /api/v2/api_keys/{api_key_id} | Get API key
*KeyManagementApi* | [**get_current_user_application_key**](KeyManagementApi.md#get_current_user_application_key) | **GET** /api/v2/current_user/application_keys/{app_key_id} | Get one application key owned by current user
*KeyManagementApi* | [**list_api_keys**](KeyManagementApi.md#list_api_keys) | **GET** /api/v2/api_keys | Get all API keys
*KeyManagementApi* | [**list_application_keys**](KeyManagementApi.md#list_application_keys) | **GET** /api/v2/application_keys | Get all application keys
*KeyManagementApi* | [**list_current_user_application_keys**](KeyManagementApi.md#list_current_user_application_keys) | **GET** /api/v2/current_user/application_keys | Get all application keys owned by current user
*KeyManagementApi* | [**update_api_key**](KeyManagementApi.md#update_api_key) | **PATCH** /api/v2/api_keys/{api_key_id} | Edit an API key
*KeyManagementApi* | [**update_application_key**](KeyManagementApi.md#update_application_key) | **PATCH** /api/v2/application_keys/{app_key_id} | Edit an application key
*KeyManagementApi* | [**update_current_user_application_key**](KeyManagementApi.md#update_current_user_application_key) | **PATCH** /api/v2/current_user/application_keys/{app_key_id} | Edit an application key owned by current user
*LogsApi* | [**aggregate_logs**](LogsApi.md#aggregate_logs) | **POST** /api/v2/logs/analytics/aggregate | Aggregate events
*LogsApi* | [**list_logs**](LogsApi.md#list_logs) | **POST** /api/v2/logs/events/search | Search logs
*LogsApi* | [**list_logs_get**](LogsApi.md#list_logs_get) | **GET** /api/v2/logs/events | Get a list of logs
*LogsArchivesApi* | [**add_read_role_to_archive**](LogsArchivesApi.md#add_read_role_to_archive) | **POST** /api/v2/logs/config/archives/{archive_id}/readers | Grant role to an archive
*LogsArchivesApi* | [**create_logs_archive**](LogsArchivesApi.md#create_logs_archive) | **POST** /api/v2/logs/config/archives | Create an archive
*LogsArchivesApi* | [**delete_logs_archive**](LogsArchivesApi.md#delete_logs_archive) | **DELETE** /api/v2/logs/config/archives/{archive_id} | Delete an archive
*LogsArchivesApi* | [**get_logs_archive**](LogsArchivesApi.md#get_logs_archive) | **GET** /api/v2/logs/config/archives/{archive_id} | Get an archive
*LogsArchivesApi* | [**get_logs_archive_order**](LogsArchivesApi.md#get_logs_archive_order) | **GET** /api/v2/logs/config/archive-order | Get archive order
*LogsArchivesApi* | [**list_archive_read_roles**](LogsArchivesApi.md#list_archive_read_roles) | **GET** /api/v2/logs/config/archives/{archive_id}/readers | List read roles for an archive
*LogsArchivesApi* | [**list_logs_archives**](LogsArchivesApi.md#list_logs_archives) | **GET** /api/v2/logs/config/archives | Get all archives
*LogsArchivesApi* | [**remove_role_from_archive**](LogsArchivesApi.md#remove_role_from_archive) | **DELETE** /api/v2/logs/config/archives/{archive_id}/readers | Revoke role from an archive
*LogsArchivesApi* | [**update_logs_archive**](LogsArchivesApi.md#update_logs_archive) | **PUT** /api/v2/logs/config/archives/{archive_id} | Update an archive
*LogsArchivesApi* | [**update_logs_archive_order**](LogsArchivesApi.md#update_logs_archive_order) | **PUT** /api/v2/logs/config/archive-order | Update archive order
*LogsMetricsApi* | [**create_logs_metric**](LogsMetricsApi.md#create_logs_metric) | **POST** /api/v2/logs/config/metrics | Create a log-based metric
*LogsMetricsApi* | [**delete_logs_metric**](LogsMetricsApi.md#delete_logs_metric) | **DELETE** /api/v2/logs/config/metrics/{metric_id} | Delete a log-based metric
*LogsMetricsApi* | [**get_logs_metric**](LogsMetricsApi.md#get_logs_metric) | **GET** /api/v2/logs/config/metrics/{metric_id} | Get a log-based metric
*LogsMetricsApi* | [**list_logs_metrics**](LogsMetricsApi.md#list_logs_metrics) | **GET** /api/v2/logs/config/metrics | Get all log-based metrics
*LogsMetricsApi* | [**update_logs_metric**](LogsMetricsApi.md#update_logs_metric) | **PATCH** /api/v2/logs/config/metrics/{metric_id} | Update a log-based metric
*MetricsApi* | [**create_tag_configuration**](MetricsApi.md#create_tag_configuration) | **POST** /api/v2/metrics/{metric_name}/tags | Create a tag configuration
*MetricsApi* | [**delete_tag_configuration**](MetricsApi.md#delete_tag_configuration) | **DELETE** /api/v2/metrics/{metric_name}/tags | Delete a tag configuration
*MetricsApi* | [**list_tag_configuration_by_name**](MetricsApi.md#list_tag_configuration_by_name) | **GET** /api/v2/metrics/{metric_name}/tags | List tag configuration by name
*MetricsApi* | [**list_tag_configurations**](MetricsApi.md#list_tag_configurations) | **GET** /api/v2/metrics | List tag configurations
*MetricsApi* | [**list_tags_by_metric_name**](MetricsApi.md#list_tags_by_metric_name) | **GET** /api/v2/metrics/{metric_name}/all-tags | List tags by metric name
*MetricsApi* | [**list_volumes_by_metric_name**](MetricsApi.md#list_volumes_by_metric_name) | **GET** /api/v2/metrics/{metric_name}/volumes | List distinct metric volumes by metric name
*MetricsApi* | [**update_tag_configuration**](MetricsApi.md#update_tag_configuration) | **PATCH** /api/v2/metrics/{metric_name}/tags | Update a tag configuration
*ProcessesApi* | [**list_processes**](ProcessesApi.md#list_processes) | **GET** /api/v2/processes | Get all processes
*RolesApi* | [**add_permission_to_role**](RolesApi.md#add_permission_to_role) | **POST** /api/v2/roles/{role_id}/permissions | Grant permission to a role
*RolesApi* | [**add_user_to_role**](RolesApi.md#add_user_to_role) | **POST** /api/v2/roles/{role_id}/users | Add a user to a role
*RolesApi* | [**create_role**](RolesApi.md#create_role) | **POST** /api/v2/roles | Create role
*RolesApi* | [**delete_role**](RolesApi.md#delete_role) | **DELETE** /api/v2/roles/{role_id} | Delete role
*RolesApi* | [**get_role**](RolesApi.md#get_role) | **GET** /api/v2/roles/{role_id} | Get a role
*RolesApi* | [**list_permissions**](RolesApi.md#list_permissions) | **GET** /api/v2/permissions | List permissions
*RolesApi* | [**list_role_permissions**](RolesApi.md#list_role_permissions) | **GET** /api/v2/roles/{role_id}/permissions | List permissions for a role
*RolesApi* | [**list_role_users**](RolesApi.md#list_role_users) | **GET** /api/v2/roles/{role_id}/users | Get all users of a role
*RolesApi* | [**list_roles**](RolesApi.md#list_roles) | **GET** /api/v2/roles | List roles
*RolesApi* | [**remove_permission_from_role**](RolesApi.md#remove_permission_from_role) | **DELETE** /api/v2/roles/{role_id}/permissions | Revoke permission
*RolesApi* | [**remove_user_from_role**](RolesApi.md#remove_user_from_role) | **DELETE** /api/v2/roles/{role_id}/users | Remove a user from a role
*RolesApi* | [**update_role**](RolesApi.md#update_role) | **PATCH** /api/v2/roles/{role_id} | Update a role
*SecurityMonitoringApi* | [**create_security_monitoring_rule**](SecurityMonitoringApi.md#create_security_monitoring_rule) | **POST** /api/v2/security_monitoring/rules | Create a detection rule
*SecurityMonitoringApi* | [**delete_security_monitoring_rule**](SecurityMonitoringApi.md#delete_security_monitoring_rule) | **DELETE** /api/v2/security_monitoring/rules/{rule_id} | Delete an existing rule
*SecurityMonitoringApi* | [**get_security_monitoring_rule**](SecurityMonitoringApi.md#get_security_monitoring_rule) | **GET** /api/v2/security_monitoring/rules/{rule_id} | Get a rule&#39;s details
*SecurityMonitoringApi* | [**list_security_monitoring_rules**](SecurityMonitoringApi.md#list_security_monitoring_rules) | **GET** /api/v2/security_monitoring/rules | List rules
*SecurityMonitoringApi* | [**list_security_monitoring_signals**](SecurityMonitoringApi.md#list_security_monitoring_signals) | **GET** /api/v2/security_monitoring/signals | Get a quick list of security signals
*SecurityMonitoringApi* | [**search_security_monitoring_signals**](SecurityMonitoringApi.md#search_security_monitoring_signals) | **POST** /api/v2/security_monitoring/signals/search | Get a list of security signals
*SecurityMonitoringApi* | [**update_security_monitoring_rule**](SecurityMonitoringApi.md#update_security_monitoring_rule) | **PUT** /api/v2/security_monitoring/rules/{rule_id} | Update an existing rule
*UsersApi* | [**create_user**](UsersApi.md#create_user) | **POST** /api/v2/users | Create a user
*UsersApi* | [**disable_user**](UsersApi.md#disable_user) | **DELETE** /api/v2/users/{user_id} | Disable a user
*UsersApi* | [**get_invitation**](UsersApi.md#get_invitation) | **GET** /api/v2/user_invitations/{user_invitation_uuid} | Get a user invitation
*UsersApi* | [**get_user**](UsersApi.md#get_user) | **GET** /api/v2/users/{user_id} | Get user details
*UsersApi* | [**list_user_organizations**](UsersApi.md#list_user_organizations) | **GET** /api/v2/users/{user_id}/orgs | Get a user organization
*UsersApi* | [**list_user_permissions**](UsersApi.md#list_user_permissions) | **GET** /api/v2/users/{user_id}/permissions | Get a user permissions
*UsersApi* | [**list_users**](UsersApi.md#list_users) | **GET** /api/v2/users | List all users
*UsersApi* | [**send_invitations**](UsersApi.md#send_invitations) | **POST** /api/v2/user_invitations | Send invitation emails
*UsersApi* | [**update_user**](UsersApi.md#update_user) | **PATCH** /api/v2/users/{user_id} | Update a user


## Documentation For Models

 - [APIErrorResponse](APIErrorResponse.md)
 - [APIKeyCreateAttributes](APIKeyCreateAttributes.md)
 - [APIKeyCreateData](APIKeyCreateData.md)
 - [APIKeyCreateRequest](APIKeyCreateRequest.md)
 - [APIKeyRelationships](APIKeyRelationships.md)
 - [APIKeyResponse](APIKeyResponse.md)
 - [APIKeyResponseIncludedItem](APIKeyResponseIncludedItem.md)
 - [APIKeyUpdateAttributes](APIKeyUpdateAttributes.md)
 - [APIKeyUpdateData](APIKeyUpdateData.md)
 - [APIKeyUpdateRequest](APIKeyUpdateRequest.md)
 - [APIKeysResponse](APIKeysResponse.md)
 - [APIKeysSort](APIKeysSort.md)
 - [APIKeysType](APIKeysType.md)
 - [ApplicationKeyCreateAttributes](ApplicationKeyCreateAttributes.md)
 - [ApplicationKeyCreateData](ApplicationKeyCreateData.md)
 - [ApplicationKeyCreateRequest](ApplicationKeyCreateRequest.md)
 - [ApplicationKeyRelationships](ApplicationKeyRelationships.md)
 - [ApplicationKeyResponse](ApplicationKeyResponse.md)
 - [ApplicationKeyResponseIncludedItem](ApplicationKeyResponseIncludedItem.md)
 - [ApplicationKeyUpdateAttributes](ApplicationKeyUpdateAttributes.md)
 - [ApplicationKeyUpdateData](ApplicationKeyUpdateData.md)
 - [ApplicationKeyUpdateRequest](ApplicationKeyUpdateRequest.md)
 - [ApplicationKeysSort](ApplicationKeysSort.md)
 - [ApplicationKeysType](ApplicationKeysType.md)
 - [Creator](Creator.md)
 - [DashboardListAddItemsRequest](DashboardListAddItemsRequest.md)
 - [DashboardListAddItemsResponse](DashboardListAddItemsResponse.md)
 - [DashboardListDeleteItemsRequest](DashboardListDeleteItemsRequest.md)
 - [DashboardListDeleteItemsResponse](DashboardListDeleteItemsResponse.md)
 - [DashboardListItem](DashboardListItem.md)
 - [DashboardListItemRequest](DashboardListItemRequest.md)
 - [DashboardListItemResponse](DashboardListItemResponse.md)
 - [DashboardListItems](DashboardListItems.md)
 - [DashboardListUpdateItemsRequest](DashboardListUpdateItemsRequest.md)
 - [DashboardListUpdateItemsResponse](DashboardListUpdateItemsResponse.md)
 - [DashboardType](DashboardType.md)
 - [FullAPIKey](FullAPIKey.md)
 - [FullAPIKeyAttributes](FullAPIKeyAttributes.md)
 - [FullApplicationKey](FullApplicationKey.md)
 - [FullApplicationKeyAttributes](FullApplicationKeyAttributes.md)
 - [IncidentCreateAttributes](IncidentCreateAttributes.md)
 - [IncidentCreateData](IncidentCreateData.md)
 - [IncidentCreateRelationships](IncidentCreateRelationships.md)
 - [IncidentCreateRequest](IncidentCreateRequest.md)
 - [IncidentFieldAttributes](IncidentFieldAttributes.md)
 - [IncidentFieldAttributesMultipleValue](IncidentFieldAttributesMultipleValue.md)
 - [IncidentFieldAttributesSingleValue](IncidentFieldAttributesSingleValue.md)
 - [IncidentFieldAttributesSingleValueType](IncidentFieldAttributesSingleValueType.md)
 - [IncidentFieldAttributesValueType](IncidentFieldAttributesValueType.md)
 - [IncidentIntegrationMetadataType](IncidentIntegrationMetadataType.md)
 - [IncidentPostmortemType](IncidentPostmortemType.md)
 - [IncidentRelatedObject](IncidentRelatedObject.md)
 - [IncidentResponse](IncidentResponse.md)
 - [IncidentResponseAttributes](IncidentResponseAttributes.md)
 - [IncidentResponseData](IncidentResponseData.md)
 - [IncidentResponseIncludedItem](IncidentResponseIncludedItem.md)
 - [IncidentResponseRelationships](IncidentResponseRelationships.md)
 - [IncidentServiceCreateAttributes](IncidentServiceCreateAttributes.md)
 - [IncidentServiceCreateData](IncidentServiceCreateData.md)
 - [IncidentServiceCreateRequest](IncidentServiceCreateRequest.md)
 - [IncidentServiceIncludedItems](IncidentServiceIncludedItems.md)
 - [IncidentServiceRelationships](IncidentServiceRelationships.md)
 - [IncidentServiceResponse](IncidentServiceResponse.md)
 - [IncidentServiceResponseAttributes](IncidentServiceResponseAttributes.md)
 - [IncidentServiceResponseData](IncidentServiceResponseData.md)
 - [IncidentServiceType](IncidentServiceType.md)
 - [IncidentServiceUpdateAttributes](IncidentServiceUpdateAttributes.md)
 - [IncidentServiceUpdateData](IncidentServiceUpdateData.md)
 - [IncidentServiceUpdateRequest](IncidentServiceUpdateRequest.md)
 - [IncidentServicesResponse](IncidentServicesResponse.md)
 - [IncidentServicesResponseMeta](IncidentServicesResponseMeta.md)
 - [IncidentServicesResponseMetaPagination](IncidentServicesResponseMetaPagination.md)
 - [IncidentTeamCreateAttributes](IncidentTeamCreateAttributes.md)
 - [IncidentTeamCreateData](IncidentTeamCreateData.md)
 - [IncidentTeamCreateRequest](IncidentTeamCreateRequest.md)
 - [IncidentTeamIncludedItems](IncidentTeamIncludedItems.md)
 - [IncidentTeamRelationships](IncidentTeamRelationships.md)
 - [IncidentTeamResponse](IncidentTeamResponse.md)
 - [IncidentTeamResponseAttributes](IncidentTeamResponseAttributes.md)
 - [IncidentTeamResponseData](IncidentTeamResponseData.md)
 - [IncidentTeamType](IncidentTeamType.md)
 - [IncidentTeamUpdateAttributes](IncidentTeamUpdateAttributes.md)
 - [IncidentTeamUpdateData](IncidentTeamUpdateData.md)
 - [IncidentTeamUpdateRequest](IncidentTeamUpdateRequest.md)
 - [IncidentTeamsResponse](IncidentTeamsResponse.md)
 - [IncidentTimelineCellCreateAttributes](IncidentTimelineCellCreateAttributes.md)
 - [IncidentTimelineCellMarkdownContentType](IncidentTimelineCellMarkdownContentType.md)
 - [IncidentTimelineCellMarkdownCreateAttributes](IncidentTimelineCellMarkdownCreateAttributes.md)
 - [IncidentTimelineCellMarkdownCreateAttributesContent](IncidentTimelineCellMarkdownCreateAttributesContent.md)
 - [IncidentType](IncidentType.md)
 - [IncidentUpdateAttributes](IncidentUpdateAttributes.md)
 - [IncidentUpdateData](IncidentUpdateData.md)
 - [IncidentUpdateRelationships](IncidentUpdateRelationships.md)
 - [IncidentUpdateRequest](IncidentUpdateRequest.md)
 - [IncidentsResponse](IncidentsResponse.md)
 - [ListApplicationKeysResponse](ListApplicationKeysResponse.md)
 - [Log](Log.md)
 - [LogAttributes](LogAttributes.md)
 - [LogType](LogType.md)
 - [LogsAggregateBucket](LogsAggregateBucket.md)
 - [LogsAggregateBucketValue](LogsAggregateBucketValue.md)
 - [LogsAggregateBucketValueTimeseries](LogsAggregateBucketValueTimeseries.md)
 - [LogsAggregateBucketValueTimeseriesPoint](LogsAggregateBucketValueTimeseriesPoint.md)
 - [LogsAggregateRequest](LogsAggregateRequest.md)
 - [LogsAggregateRequestPage](LogsAggregateRequestPage.md)
 - [LogsAggregateResponse](LogsAggregateResponse.md)
 - [LogsAggregateResponseData](LogsAggregateResponseData.md)
 - [LogsAggregateResponseStatus](LogsAggregateResponseStatus.md)
 - [LogsAggregateSort](LogsAggregateSort.md)
 - [LogsAggregateSortType](LogsAggregateSortType.md)
 - [LogsAggregationFunction](LogsAggregationFunction.md)
 - [LogsArchive](LogsArchive.md)
 - [LogsArchiveAttributes](LogsArchiveAttributes.md)
 - [LogsArchiveCreateRequest](LogsArchiveCreateRequest.md)
 - [LogsArchiveCreateRequestAttributes](LogsArchiveCreateRequestAttributes.md)
 - [LogsArchiveCreateRequestDefinition](LogsArchiveCreateRequestDefinition.md)
 - [LogsArchiveCreateRequestDestination](LogsArchiveCreateRequestDestination.md)
 - [LogsArchiveDefinition](LogsArchiveDefinition.md)
 - [LogsArchiveDestination](LogsArchiveDestination.md)
 - [LogsArchiveDestinationAzure](LogsArchiveDestinationAzure.md)
 - [LogsArchiveDestinationAzureType](LogsArchiveDestinationAzureType.md)
 - [LogsArchiveDestinationGCS](LogsArchiveDestinationGCS.md)
 - [LogsArchiveDestinationGCSType](LogsArchiveDestinationGCSType.md)
 - [LogsArchiveDestinationS3](LogsArchiveDestinationS3.md)
 - [LogsArchiveDestinationS3Type](LogsArchiveDestinationS3Type.md)
 - [LogsArchiveIntegrationAzure](LogsArchiveIntegrationAzure.md)
 - [LogsArchiveIntegrationGCS](LogsArchiveIntegrationGCS.md)
 - [LogsArchiveIntegrationS3](LogsArchiveIntegrationS3.md)
 - [LogsArchiveOrder](LogsArchiveOrder.md)
 - [LogsArchiveOrderAttributes](LogsArchiveOrderAttributes.md)
 - [LogsArchiveOrderDefinition](LogsArchiveOrderDefinition.md)
 - [LogsArchiveOrderDefinitionType](LogsArchiveOrderDefinitionType.md)
 - [LogsArchiveState](LogsArchiveState.md)
 - [LogsArchives](LogsArchives.md)
 - [LogsCompute](LogsCompute.md)
 - [LogsComputeType](LogsComputeType.md)
 - [LogsGroupBy](LogsGroupBy.md)
 - [LogsGroupByHistogram](LogsGroupByHistogram.md)
 - [LogsGroupByMissing](LogsGroupByMissing.md)
 - [LogsGroupByTotal](LogsGroupByTotal.md)
 - [LogsListRequest](LogsListRequest.md)
 - [LogsListRequestPage](LogsListRequestPage.md)
 - [LogsListResponse](LogsListResponse.md)
 - [LogsListResponseLinks](LogsListResponseLinks.md)
 - [LogsMetricCompute](LogsMetricCompute.md)
 - [LogsMetricComputeAggregationType](LogsMetricComputeAggregationType.md)
 - [LogsMetricCreateAttributes](LogsMetricCreateAttributes.md)
 - [LogsMetricCreateData](LogsMetricCreateData.md)
 - [LogsMetricCreateRequest](LogsMetricCreateRequest.md)
 - [LogsMetricFilter](LogsMetricFilter.md)
 - [LogsMetricGroupBy](LogsMetricGroupBy.md)
 - [LogsMetricResponse](LogsMetricResponse.md)
 - [LogsMetricResponseAttributes](LogsMetricResponseAttributes.md)
 - [LogsMetricResponseCompute](LogsMetricResponseCompute.md)
 - [LogsMetricResponseComputeAggregationType](LogsMetricResponseComputeAggregationType.md)
 - [LogsMetricResponseData](LogsMetricResponseData.md)
 - [LogsMetricResponseFilter](LogsMetricResponseFilter.md)
 - [LogsMetricResponseGroupBy](LogsMetricResponseGroupBy.md)
 - [LogsMetricType](LogsMetricType.md)
 - [LogsMetricUpdateAttributes](LogsMetricUpdateAttributes.md)
 - [LogsMetricUpdateData](LogsMetricUpdateData.md)
 - [LogsMetricUpdateRequest](LogsMetricUpdateRequest.md)
 - [LogsMetricsResponse](LogsMetricsResponse.md)
 - [LogsQueryFilter](LogsQueryFilter.md)
 - [LogsQueryOptions](LogsQueryOptions.md)
 - [LogsResponseMetadata](LogsResponseMetadata.md)
 - [LogsResponseMetadataPage](LogsResponseMetadataPage.md)
 - [LogsSort](LogsSort.md)
 - [LogsSortOrder](LogsSortOrder.md)
 - [LogsWarning](LogsWarning.md)
 - [Metric](Metric.md)
 - [MetricAllTags](MetricAllTags.md)
 - [MetricAllTagsAttributes](MetricAllTagsAttributes.md)
 - [MetricAllTagsResponse](MetricAllTagsResponse.md)
 - [MetricDistinctVolume](MetricDistinctVolume.md)
 - [MetricDistinctVolumeAttributes](MetricDistinctVolumeAttributes.md)
 - [MetricDistinctVolumeType](MetricDistinctVolumeType.md)
 - [MetricIngestedIndexedVolume](MetricIngestedIndexedVolume.md)
 - [MetricIngestedIndexedVolumeAttributes](MetricIngestedIndexedVolumeAttributes.md)
 - [MetricIngestedIndexedVolumeType](MetricIngestedIndexedVolumeType.md)
 - [MetricTagConfiguration](MetricTagConfiguration.md)
 - [MetricTagConfigurationAttributes](MetricTagConfigurationAttributes.md)
 - [MetricTagConfigurationCreateAttributes](MetricTagConfigurationCreateAttributes.md)
 - [MetricTagConfigurationCreateData](MetricTagConfigurationCreateData.md)
 - [MetricTagConfigurationCreateRequest](MetricTagConfigurationCreateRequest.md)
 - [MetricTagConfigurationMetricTypes](MetricTagConfigurationMetricTypes.md)
 - [MetricTagConfigurationResponse](MetricTagConfigurationResponse.md)
 - [MetricTagConfigurationType](MetricTagConfigurationType.md)
 - [MetricTagConfigurationUpdateAttributes](MetricTagConfigurationUpdateAttributes.md)
 - [MetricTagConfigurationUpdateData](MetricTagConfigurationUpdateData.md)
 - [MetricTagConfigurationUpdateRequest](MetricTagConfigurationUpdateRequest.md)
 - [MetricType](MetricType.md)
 - [MetricVolumes](MetricVolumes.md)
 - [MetricVolumesResponse](MetricVolumesResponse.md)
 - [MetricsAndMetricTagConfigurations](MetricsAndMetricTagConfigurations.md)
 - [MetricsAndMetricTagConfigurationsResponse](MetricsAndMetricTagConfigurationsResponse.md)
 - [Organization](Organization.md)
 - [OrganizationAttributes](OrganizationAttributes.md)
 - [OrganizationsType](OrganizationsType.md)
 - [Pagination](Pagination.md)
 - [PartialAPIKey](PartialAPIKey.md)
 - [PartialAPIKeyAttributes](PartialAPIKeyAttributes.md)
 - [PartialApplicationKey](PartialApplicationKey.md)
 - [PartialApplicationKeyAttributes](PartialApplicationKeyAttributes.md)
 - [Permission](Permission.md)
 - [PermissionAttributes](PermissionAttributes.md)
 - [PermissionsResponse](PermissionsResponse.md)
 - [PermissionsType](PermissionsType.md)
 - [ProcessSummariesMeta](ProcessSummariesMeta.md)
 - [ProcessSummariesMetaPage](ProcessSummariesMetaPage.md)
 - [ProcessSummariesResponse](ProcessSummariesResponse.md)
 - [ProcessSummary](ProcessSummary.md)
 - [ProcessSummaryAttributes](ProcessSummaryAttributes.md)
 - [ProcessSummaryType](ProcessSummaryType.md)
 - [QuerySortOrder](QuerySortOrder.md)
 - [RelationshipToIncidentIntegrationMetadataData](RelationshipToIncidentIntegrationMetadataData.md)
 - [RelationshipToIncidentIntegrationMetadatas](RelationshipToIncidentIntegrationMetadatas.md)
 - [RelationshipToIncidentPostmortem](RelationshipToIncidentPostmortem.md)
 - [RelationshipToIncidentPostmortemData](RelationshipToIncidentPostmortemData.md)
 - [RelationshipToOrganization](RelationshipToOrganization.md)
 - [RelationshipToOrganizationData](RelationshipToOrganizationData.md)
 - [RelationshipToOrganizations](RelationshipToOrganizations.md)
 - [RelationshipToPermission](RelationshipToPermission.md)
 - [RelationshipToPermissionData](RelationshipToPermissionData.md)
 - [RelationshipToPermissions](RelationshipToPermissions.md)
 - [RelationshipToRole](RelationshipToRole.md)
 - [RelationshipToRoleData](RelationshipToRoleData.md)
 - [RelationshipToRoles](RelationshipToRoles.md)
 - [RelationshipToUser](RelationshipToUser.md)
 - [RelationshipToUserData](RelationshipToUserData.md)
 - [RelationshipToUsers](RelationshipToUsers.md)
 - [ResponseMetaAttributes](ResponseMetaAttributes.md)
 - [Role](Role.md)
 - [RoleAttributes](RoleAttributes.md)
 - [RoleCreateAttributes](RoleCreateAttributes.md)
 - [RoleCreateData](RoleCreateData.md)
 - [RoleCreateRequest](RoleCreateRequest.md)
 - [RoleCreateResponse](RoleCreateResponse.md)
 - [RoleCreateResponseData](RoleCreateResponseData.md)
 - [RoleRelationships](RoleRelationships.md)
 - [RoleResponse](RoleResponse.md)
 - [RoleResponseRelationships](RoleResponseRelationships.md)
 - [RoleUpdateAttributes](RoleUpdateAttributes.md)
 - [RoleUpdateData](RoleUpdateData.md)
 - [RoleUpdateRequest](RoleUpdateRequest.md)
 - [RoleUpdateResponse](RoleUpdateResponse.md)
 - [RoleUpdateResponseData](RoleUpdateResponseData.md)
 - [RolesResponse](RolesResponse.md)
 - [RolesSort](RolesSort.md)
 - [RolesType](RolesType.md)
 - [SecurityMonitoringFilter](SecurityMonitoringFilter.md)
 - [SecurityMonitoringFilterAction](SecurityMonitoringFilterAction.md)
 - [SecurityMonitoringListRulesResponse](SecurityMonitoringListRulesResponse.md)
 - [SecurityMonitoringRuleCase](SecurityMonitoringRuleCase.md)
 - [SecurityMonitoringRuleCaseCreate](SecurityMonitoringRuleCaseCreate.md)
 - [SecurityMonitoringRuleCreatePayload](SecurityMonitoringRuleCreatePayload.md)
 - [SecurityMonitoringRuleDetectionMethod](SecurityMonitoringRuleDetectionMethod.md)
 - [SecurityMonitoringRuleEvaluationWindow](SecurityMonitoringRuleEvaluationWindow.md)
 - [SecurityMonitoringRuleKeepAlive](SecurityMonitoringRuleKeepAlive.md)
 - [SecurityMonitoringRuleMaxSignalDuration](SecurityMonitoringRuleMaxSignalDuration.md)
 - [SecurityMonitoringRuleNewValueOptions](SecurityMonitoringRuleNewValueOptions.md)
 - [SecurityMonitoringRuleNewValueOptionsForgetAfter](SecurityMonitoringRuleNewValueOptionsForgetAfter.md)
 - [SecurityMonitoringRuleNewValueOptionsLearningDuration](SecurityMonitoringRuleNewValueOptionsLearningDuration.md)
 - [SecurityMonitoringRuleOptions](SecurityMonitoringRuleOptions.md)
 - [SecurityMonitoringRuleQuery](SecurityMonitoringRuleQuery.md)
 - [SecurityMonitoringRuleQueryAggregation](SecurityMonitoringRuleQueryAggregation.md)
 - [SecurityMonitoringRuleQueryCreate](SecurityMonitoringRuleQueryCreate.md)
 - [SecurityMonitoringRuleResponse](SecurityMonitoringRuleResponse.md)
 - [SecurityMonitoringRuleSeverity](SecurityMonitoringRuleSeverity.md)
 - [SecurityMonitoringRuleUpdatePayload](SecurityMonitoringRuleUpdatePayload.md)
 - [SecurityMonitoringSignal](SecurityMonitoringSignal.md)
 - [SecurityMonitoringSignalAttributes](SecurityMonitoringSignalAttributes.md)
 - [SecurityMonitoringSignalListRequest](SecurityMonitoringSignalListRequest.md)
 - [SecurityMonitoringSignalListRequestFilter](SecurityMonitoringSignalListRequestFilter.md)
 - [SecurityMonitoringSignalListRequestPage](SecurityMonitoringSignalListRequestPage.md)
 - [SecurityMonitoringSignalType](SecurityMonitoringSignalType.md)
 - [SecurityMonitoringSignalsListResponse](SecurityMonitoringSignalsListResponse.md)
 - [SecurityMonitoringSignalsListResponseLinks](SecurityMonitoringSignalsListResponseLinks.md)
 - [SecurityMonitoringSignalsListResponseMeta](SecurityMonitoringSignalsListResponseMeta.md)
 - [SecurityMonitoringSignalsListResponseMetaPage](SecurityMonitoringSignalsListResponseMetaPage.md)
 - [SecurityMonitoringSignalsSort](SecurityMonitoringSignalsSort.md)
 - [User](User.md)
 - [UserAttributes](UserAttributes.md)
 - [UserCreateAttributes](UserCreateAttributes.md)
 - [UserCreateData](UserCreateData.md)
 - [UserCreateRequest](UserCreateRequest.md)
 - [UserInvitationData](UserInvitationData.md)
 - [UserInvitationDataAttributes](UserInvitationDataAttributes.md)
 - [UserInvitationRelationships](UserInvitationRelationships.md)
 - [UserInvitationResponse](UserInvitationResponse.md)
 - [UserInvitationResponseData](UserInvitationResponseData.md)
 - [UserInvitationsRequest](UserInvitationsRequest.md)
 - [UserInvitationsResponse](UserInvitationsResponse.md)
 - [UserInvitationsType](UserInvitationsType.md)
 - [UserRelationships](UserRelationships.md)
 - [UserResponse](UserResponse.md)
 - [UserResponseIncludedItem](UserResponseIncludedItem.md)
 - [UserResponseRelationships](UserResponseRelationships.md)
 - [UserUpdateAttributes](UserUpdateAttributes.md)
 - [UserUpdateData](UserUpdateData.md)
 - [UserUpdateRequest](UserUpdateRequest.md)
 - [UsersResponse](UsersResponse.md)
 - [UsersType](UsersType.md)


## Documentation For Authorization


## apiKeyAuth

- **Type**: API key
- **API key parameter name**: DD-API-KEY
- **Location**: HTTP header


## appKeyAuth

- **Type**: API key
- **API key parameter name**: DD-APPLICATION-KEY
- **Location**: HTTP header


## Author

support@datadoghq.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in datadog_api_client.v2.apis and datadog_api_client.v2.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from datadog_api_client.v2.api.default_api import DefaultApi`
- `from datadog_api_client.v2.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import datadog_api_client.v2
from datadog_api_client.v2.apis import *
from datadog_api_client.v2.models import *
```

